/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtQuickAPI_H
#define _QtQuickAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_Wayland
#define SIP_FEATURE_PyQt_XCB
#define SIP_FEATURE_PyQt_Permissions
#define SIP_FEATURE_PyQt_DTLS
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_Linux
#define SIP_TIMELINE_Qt_6_11_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_0 0
#define sipName_0 &sipStrings_QtQuick[0]
#define sipNameNr_69 69
#define sipName_69 &sipStrings_QtQuick[69]
#define sipNameNr_QSGMaterialShader__GraphicsPipelineState__ColorMaskComponent 131
#define sipName_QSGMaterialShader__GraphicsPipelineState__ColorMaskComponent &sipStrings_QtQuick[131]
#define sipNameNr_192 192
#define sipName_192 &sipStrings_QtQuick[192]
#define sipNameNr_QSGMaterialShader__GraphicsPipelineState__BlendFactor 246
#define sipName_QSGMaterialShader__GraphicsPipelineState__BlendFactor &sipStrings_QtQuick[246]
#define sipNameNr_QSGMaterialShader__GraphicsPipelineState__PolygonMode 300
#define sipName_QSGMaterialShader__GraphicsPipelineState__PolygonMode &sipStrings_QtQuick[300]
#define sipNameNr_QSGSimpleTextureNode__TextureCoordinatesTransformFlag 354
#define sipName_QSGSimpleTextureNode__TextureCoordinatesTransformFlag &sipStrings_QtQuick[354]
#define sipNameNr_408 408
#define sipName_408 &sipStrings_QtQuick[408]
#define sipNameNr_460 460
#define sipName_460 &sipStrings_QtQuick[460]
#define sipNameNr_QSGMaterialShader__GraphicsPipelineState__CullMode 511
#define sipName_QSGMaterialShader__GraphicsPipelineState__CullMode &sipStrings_QtQuick[511]
#define sipNameNr_QSGMaterialShader__GraphicsPipelineState__BlendOp 562
#define sipName_QSGMaterialShader__GraphicsPipelineState__BlendOp &sipStrings_QtQuick[562]
#define sipNameNr_612 612
#define sipName_612 &sipStrings_QtQuick[612]
#define sipNameNr_QSGImageNode__TextureCoordinatesTransformFlag 659
#define sipName_QSGImageNode__TextureCoordinatesTransformFlag &sipStrings_QtQuick[659]
#define sipNameNr_QSGRendererInterface__ShaderCompilationType 705
#define sipName_QSGRendererInterface__ShaderCompilationType &sipStrings_QtQuick[705]
#define sipNameNr_749 749
#define sipName_749 &sipStrings_QtQuick[749]
#define sipNameNr_QSGMaterialShader__RenderState__DirtyState 792
#define sipName_QSGMaterialShader__RenderState__DirtyState &sipStrings_QtQuick[792]
#define sipNameNr_835 835
#define sipName_835 &sipStrings_QtQuick[835]
#define sipNameNr_QSGMaterialShader__GraphicsPipelineState 877
#define sipName_QSGMaterialShader__GraphicsPipelineState &sipStrings_QtQuick[877]
#define sipNameNr_QSGRendererInterface__ShaderSourceType 918
#define sipName_QSGRendererInterface__ShaderSourceType &sipStrings_QtQuick[918]
#define sipNameNr_957 957
#define sipName_957 &sipStrings_QtQuick[957]
#define sipNameNr_QNativeInterface__QSGOpenGLTexture 994
#define sipName_QNativeInterface__QSGOpenGLTexture &sipStrings_QtQuick[994]
#define sipNameNr_QQuickPaintedItem__PerformanceHint 1029
#define sipName_QQuickPaintedItem__PerformanceHint &sipStrings_QtQuick[1029]
#define sipNameNr_QQuickFramebufferObject__Renderer 1064
#define sipName_QQuickFramebufferObject__Renderer &sipStrings_QtQuick[1064]
#define sipNameNr_QQuickWindow__CreateTextureOption 1098
#define sipName_QQuickWindow__CreateTextureOption &sipStrings_QtQuick[1098]
#define sipNameNr_QSGRendererInterface__GraphicsApi 1132
#define sipName_QSGRendererInterface__GraphicsApi &sipStrings_QtQuick[1132]
#define sipNameNr_RequiresFullMatrixExceptTranslate 1166
#define sipName_RequiresFullMatrixExceptTranslate &sipStrings_QtQuick[1166]
#define sipNameNr_defaultAttributes_TexturedPoint2D 1200
#define sipName_defaultAttributes_TexturedPoint2D &sipStrings_QtQuick[1200]
#define sipNameNr_GraphicsQueueFamilyIndexResource 1234
#define sipName_GraphicsQueueFamilyIndexResource &sipStrings_QtQuick[1234]
#define sipNameNr_1267 1267
#define sipName_1267 &sipStrings_QtQuick[1267]
#define sipNameNr_1300 1300
#define sipName_1300 &sipStrings_QtQuick[1300]
#define sipNameNr_QSGRendererInterface__RenderMode 1333
#define sipName_QSGRendererInterface__RenderMode &sipStrings_QtQuick[1333]
#define sipNameNr_QSGRendererInterface__ShaderType 1366
#define sipName_QSGRendererInterface__ShaderType &sipStrings_QtQuick[1366]
#define sipNameNr_defaultAttributes_ColoredPoint2D 1399
#define sipName_defaultAttributes_ColoredPoint2D &sipStrings_QtQuick[1399]
#define sipNameNr_1432 1432
#define sipName_1432 &sipStrings_QtQuick[1432]
#define sipNameNr_QQuickItem__UpdatePaintNodeData 1464
#define sipName_QQuickItem__UpdatePaintNodeData &sipStrings_QtQuick[1464]
#define sipNameNr_QQuickPaintedItem__RenderTarget 1496
#define sipName_QQuickPaintedItem__RenderTarget &sipStrings_QtQuick[1496]
#define sipNameNr_TextureCoordinatesTransformFlag 376
#define sipName_TextureCoordinatesTransformFlag &sipStrings_QtQuick[376]
#define sipNameNr_isAutomaticPipelineCacheEnabled 1528
#define sipName_isAutomaticPipelineCacheEnabled &sipStrings_QtQuick[1528]
#define sipNameNr_ItemDevicePixelRatioHasChanged 1560
#define sipName_ItemDevicePixelRatioHasChanged &sipStrings_QtQuick[1560]
#define sipNameNr_1591 1591
#define sipName_1591 &sipStrings_QtQuick[1591]
#define sipNameNr_QSGMaterialShader__RenderState 1622
#define sipName_QSGMaterialShader__RenderState &sipStrings_QtQuick[1622]
#define sipNameNr_QSGRendererInterface__Resource 1653
#define sipName_QSGRendererInterface__Resource &sipStrings_QtQuick[1653]
#define sipNameNr_setTextureCoordinatesTransform 1684
#define sipName_setTextureCoordinatesTransform &sipStrings_QtQuick[1684]
#define sipNameNr_QQuickWindow__SceneGraphError 1715
#define sipName_QQuickWindow__SceneGraphError &sipStrings_QtQuick[1715]
#define sipNameNr_convertToNormalizedSourceRect 1745
#define sipName_convertToNormalizedSourceRect &sipStrings_QtQuick[1745]
#define sipNameNr_textureFollowsItemSizeChanged 1775
#define sipName_textureFollowsItemSizeChanged &sipStrings_QtQuick[1775]
#define sipNameNr_QQuickWindow__TextRenderType 1805
#define sipName_QQuickWindow__TextRenderType &sipStrings_QtQuick[1805]
#define sipNameNr_QSGGeometry__TexturedPoint2D 1834
#define sipName_QSGGeometry__TexturedPoint2D &sipStrings_QtQuick[1834]
#define sipNameNr_QSGRenderNode__RenderingFlag 1863
#define sipName_QSGRenderNode__RenderingFlag &sipStrings_QtQuick[1863]
#define sipNameNr_UpdatesGraphicsPipelineState 1892
#define sipName_UpdatesGraphicsPipelineState &sipStrings_QtQuick[1892]
#define sipNameNr_QQuickGraphicsConfiguration 1921
#define sipName_QQuickGraphicsConfiguration &sipStrings_QtQuick[1921]
#define sipNameNr_QQuickItem__TransformOrigin 1949
#define sipName_QQuickItem__TransformOrigin &sipStrings_QtQuick[1949]
#define sipNameNr_QSGGeometry__ColoredPoint2D 1977
#define sipName_QSGGeometry__ColoredPoint2D &sipStrings_QtQuick[1977]
#define sipNameNr_QSGTexture__AnisotropyLevel 2005
#define sipName_QSGTexture__AnisotropyLevel &sipStrings_QtQuick[2005]
#define sipNameNr_invalidateFramebufferObject 2033
#define sipName_invalidateFramebufferObject &sipStrings_QtQuick[2033]
#define sipNameNr_preferredInstanceExtensions 2061
#define sipName_preferredInstanceExtensions &sipStrings_QtQuick[2061]
#define sipNameNr_textureCoordinatesTransform 2089
#define sipName_textureCoordinatesTransform &sipStrings_QtQuick[2089]
#define sipNameNr_updateGraphicsPipelineState 2117
#define sipName_updateGraphicsPipelineState &sipStrings_QtQuick[2117]
#define sipNameNr_vertexDataAsTexturedPoint2D 2145
#define sipName_vertexDataAsTexturedPoint2D &sipStrings_QtQuick[2145]
#define sipNameNr_GraphicsQueueIndexResource 2173
#define sipName_GraphicsQueueIndexResource &sipStrings_QtQuick[2173]
#define sipNameNr_InvertedYFramebufferObject 2200
#define sipName_InvertedYFramebufferObject &sipStrings_QtQuick[2200]
#define sipNameNr_ItemAntialiasingHasChanged 2227
#define sipName_ItemAntialiasingHasChanged &sipStrings_QtQuick[2227]
#define sipNameNr_QQuickItem__ItemChangeData 2254
#define sipName_QQuickItem__ItemChangeData &sipStrings_QtQuick[2254]
#define sipNameNr_QQuickTextDocument__Status 2281
#define sipName_QQuickTextDocument__Status &sipStrings_QtQuick[2281]
#define sipNameNr_QSGGeometry__AttributeType 2308
#define sipName_QSGGeometry__AttributeType &sipStrings_QtQuick[2308]
#define sipNameNr_QSGRenderNode__RenderState 2335
#define sipName_QSGRenderNode__RenderState &sipStrings_QtQuick[2335]
#define sipNameNr_setFiltersChildMouseEvents 2362
#define sipName_setFiltersChildMouseEvents &sipStrings_QtQuick[2362]
#define sipNameNr_updateTexturedRectGeometry 2389
#define sipName_updateTexturedRectGeometry &sipStrings_QtQuick[2389]
#define sipNameNr_vertexDataAsColoredPoint2D 2416
#define sipName_vertexDataAsColoredPoint2D &sipStrings_QtQuick[2416]
#define sipNameNr_ItemActiveFocusHasChanged 2443
#define sipName_ItemActiveFocusHasChanged &sipStrings_QtQuick[2443]
#define sipNameNr_2469 2469
#define sipName_2469 &sipStrings_QtQuick[2469]
#define sipNameNr_QQuickWindow__RenderStage 2495
#define sipName_QQuickWindow__RenderStage &sipStrings_QtQuick[2495]
#define sipNameNr_QSGGeometry__AttributeSet 2521
#define sipName_QSGGeometry__AttributeSet &sipStrings_QtQuick[2521]
#define sipNameNr_RenderMode2DNoDepthBuffer 2547
#define sipName_RenderMode2DNoDepthBuffer &sipStrings_QtQuick[2547]
#define sipNameNr_beforeRenderPassRecording 2573
#define sipName_beforeRenderPassRecording &sipStrings_QtQuick[2573]
#define sipNameNr_combinedImageSamplerCount 2599
#define sipName_combinedImageSamplerCount &sipStrings_QtQuick[2599]
#define sipNameNr_defaultAttributes_Point2D 2625
#define sipName_defaultAttributes_Point2D &sipStrings_QtQuick[2625]
#define sipNameNr_effectiveDevicePixelRatio 2651
#define sipName_effectiveDevicePixelRatio &sipStrings_QtQuick[2651]
#define sipNameNr_isDepthBufferEnabledFor2D 2677
#define sipName_isDepthBufferEnabledFor2D &sipStrings_QtQuick[2677]
#define sipNameNr_setAutomaticPipelineCache 2703
#define sipName_setAutomaticPipelineCache &sipStrings_QtQuick[2703]
#define sipNameNr_setTextureFollowsItemSize 2729
#define sipName_setTextureFollowsItemSize &sipStrings_QtQuick[2729]
#define sipNameNr_updateColoredRectGeometry 2755
#define sipName_updateColoredRectGeometry &sipStrings_QtQuick[2755]
#define sipNameNr_BeforeSynchronizingStage 2781
#define sipName_BeforeSynchronizingStage &sipStrings_QtQuick[2781]
#define sipNameNr_ItemClipsChildrenToShape 2806
#define sipName_ItemClipsChildrenToShape &sipStrings_QtQuick[2806]
#define sipNameNr_2831 2831
#define sipName_2831 &sipStrings_QtQuick[2831]
#define sipNameNr_QOpenGLFramebufferObject 2856
#define sipName_QOpenGLFramebufferObject &sipStrings_QtQuick[2856]
#define sipNameNr_QQuickAsyncImageProvider 2881
#define sipName_QQuickAsyncImageProvider &sipStrings_QtQuick[2881]
#define sipNameNr_QQuickRenderTarget__Flag 2906
#define sipName_QQuickRenderTarget__Flag &sipStrings_QtQuick[2906]
#define sipNameNr_QSGGeometry__DataPattern 2931
#define sipName_QSGGeometry__DataPattern &sipStrings_QtQuick[2931]
#define sipNameNr_QSGGeometry__DrawingMode 2956
#define sipName_QSGGeometry__DrawingMode &sipStrings_QtQuick[2956]
#define sipNameNr_QSGMaterialShader__Stage 2981
#define sipName_QSGMaterialShader__Stage &sipStrings_QtQuick[2981]
#define sipNameNr_QSGOpaqueTextureMaterial 3006
#define sipName_QSGOpaqueTextureMaterial &sipStrings_QtQuick[3006]
#define sipNameNr_QSGRenderNode__StateFlag 3031
#define sipName_QSGRenderNode__StateFlag &sipStrings_QtQuick[3031]
#define sipNameNr_RhiRedirectCommandBuffer 3056
#define sipName_RhiRedirectCommandBuffer &sipStrings_QtQuick[3056]
#define sipNameNr_afterRenderPassRecording 3081
#define sipName_afterRenderPassRecording &sipStrings_QtQuick[3081]
#define sipNameNr_normalizedTextureSubRect 3106
#define sipName_normalizedTextureSubRect &sipStrings_QtQuick[3106]
#define sipNameNr_setGraphicsConfiguration 3131
#define sipName_setGraphicsConfiguration &sipStrings_QtQuick[3131]
#define sipNameNr_setPipelineCacheLoadFile 3156
#define sipName_setPipelineCacheLoadFile &sipStrings_QtQuick[3156]
#define sipNameNr_setPipelineCacheSaveFile 3181
#define sipName_setPipelineCacheSaveFile &sipStrings_QtQuick[3181]
#define sipNameNr_AfterSynchronizingStage 3206
#define sipName_AfterSynchronizingStage &sipStrings_QtQuick[3206]
#define sipNameNr_DirtyCachedMaterialData 3230
#define sipName_DirtyCachedMaterialData &sipStrings_QtQuick[3230]
#define sipNameNr_ItemTransformHasChanged 3254
#define sipName_ItemTransformHasChanged &sipStrings_QtQuick[3254]
#define sipNameNr_PyQt6_sip_simplewrapper 3278
#define sipName_PyQt6_sip_simplewrapper &sipStrings_QtQuick[3278]
#define sipNameNr_QQuickFramebufferObject 3302
#define sipName_QQuickFramebufferObject &sipStrings_QtQuick[3302]
#define sipNameNr_QSGMaterialShader__Flag 3326
#define sipName_QSGMaterialShader__Flag &sipStrings_QtQuick[3326]
#define sipNameNr_QSGTextNode__RenderType 3350
#define sipName_QSGTextNode__RenderType &sipStrings_QtQuick[3350]
#define sipNameNr_RhiRedirectRenderTarget 3374
#define sipName_RhiRedirectRenderTarget &sipStrings_QtQuick[3374]
#define sipNameNr_activeFocusOnTabChanged 3398
#define sipName_activeFocusOnTabChanged &sipStrings_QtQuick[3398]
#define sipNameNr_createFramebufferObject 3422
#define sipName_createFramebufferObject &sipStrings_QtQuick[3422]
#define sipNameNr_createWithAttributeType 3446
#define sipName_createWithAttributeType &sipStrings_QtQuick[3446]
#define sipNameNr_devicePixelRatioChanged 3470
#define sipName_devicePixelRatioChanged &sipStrings_QtQuick[3470]
#define sipNameNr_filtersChildMouseEvents 3494
#define sipName_filtersChildMouseEvents &sipStrings_QtQuick[3494]
#define sipNameNr_isSceneGraphInitialized 3518
#define sipName_isSceneGraphInitialized &sipStrings_QtQuick[3518]
#define sipNameNr_mirrorVerticallyChanged 3542
#define sipName_mirrorVerticallyChanged &sipStrings_QtQuick[3542]
#define sipNameNr_setAcceptedMouseButtons 3566
#define sipName_setAcceptedMouseButtons &sipStrings_QtQuick[3566]
#define sipNameNr_setPersistentSceneGraph 3590
#define sipName_setPersistentSceneGraph &sipStrings_QtQuick[3590]
#define sipNameNr_setPreferSoftwareDevice 3614
#define sipName_setPreferSoftwareDevice &sipStrings_QtQuick[3614]
#define sipNameNr_CommandEncoderResource 3638
#define sipName_CommandEncoderResource &sipStrings_QtQuick[3638]
#define sipNameNr_ItemAcceptsInputMethod 3661
#define sipName_ItemAcceptsInputMethod &sipStrings_QtQuick[3661]
#define sipNameNr_ItemChildRemovedChange 3684
#define sipName_ItemChildRemovedChange &sipStrings_QtQuick[3684]
#define sipNameNr_ItemRotationHasChanged 3707
#define sipName_ItemRotationHasChanged &sipStrings_QtQuick[3707]
#define sipNameNr_PhysicalDeviceResource 3730
#define sipName_PhysicalDeviceResource &sipStrings_QtQuick[3730]
#define sipNameNr_QQuickItem__ItemChange 3753
#define sipName_QQuickItem__ItemChange &sipStrings_QtQuick[3753]
#define sipNameNr_QQuickView__ResizeMode 3776
#define sipName_QQuickView__ResizeMode &sipStrings_QtQuick[3776]
#define sipNameNr_QSGGeometry__Attribute 3799
#define sipName_QSGGeometry__Attribute &sipStrings_QtQuick[3799]
#define sipNameNr_QSGNode__DirtyStateBit 3822
#define sipName_QSGNode__DirtyStateBit &sipStrings_QtQuick[3822]
#define sipNameNr_QSGTextNode__TextStyle 3845
#define sipName_QSGTextNode__TextStyle &sipStrings_QtQuick[3845]
#define sipNameNr_QSGVertexColorMaterial 3868
#define sipName_QSGVertexColorMaterial &sipStrings_QtQuick[3868]
#define sipNameNr_TextureHasAlphaChannel 3891
#define sipName_TextureHasAlphaChannel &sipStrings_QtQuick[3891]
#define sipNameNr_UnknownShadingLanguage 3914
#define sipName_UnknownShadingLanguage &sipStrings_QtQuick[3914]
#define sipNameNr_VulkanInstanceResource 3937
#define sipName_VulkanInstanceResource &sipStrings_QtQuick[3937]
#define sipNameNr_activeFocusItemChanged 3960
#define sipName_activeFocusItemChanged &sipStrings_QtQuick[3960]
#define sipNameNr_containmentMaskChanged 3983
#define sipName_containmentMaskChanged &sipStrings_QtQuick[3983]
#define sipNameNr_createTextureFromImage 4006
#define sipName_createTextureFromImage &sipStrings_QtQuick[4006]
#define sipNameNr_fromOpenGLRenderBuffer 4029
#define sipName_fromOpenGLRenderBuffer &sipStrings_QtQuick[4029]
#define sipNameNr_isPersistentSceneGraph 4052
#define sipName_isPersistentSceneGraph &sipStrings_QtQuick[4052]
#define sipNameNr_textureFactoryForImage 4075
#define sipName_textureFactoryForImage &sipStrings_QtQuick[4075]
#define sipNameNr_textureFollowsItemSize 4098
#define sipName_textureFollowsItemSize &sipStrings_QtQuick[4098]
#define sipNameNr_transformOriginChanged 4121
#define sipName_transformOriginChanged &sipStrings_QtQuick[4121]
#define sipNameNr_DeviceContextResource 4144
#define sipName_DeviceContextResource &sipStrings_QtQuick[4144]
#define sipNameNr_GraphicsPipelineState 896
#define sipName_GraphicsPipelineState &sipStrings_QtQuick[896]
#define sipNameNr_ItemEnabledHasChanged 4166
#define sipName_ItemEnabledHasChanged &sipStrings_QtQuick[4166]
#define sipNameNr_ItemOpacityHasChanged 4188
#define sipName_ItemOpacityHasChanged &sipStrings_QtQuick[4188]
#define sipNameNr_ItemVisibleHasChanged 4210
#define sipName_ItemVisibleHasChanged &sipStrings_QtQuick[4210]
#define sipNameNr_OneMinusConstantAlpha 4232
#define sipName_OneMinusConstantAlpha &sipStrings_QtQuick[4232]
#define sipNameNr_OneMinusConstantColor 4254
#define sipName_OneMinusConstantColor &sipStrings_QtQuick[4254]
#define sipNameNr_OpenGLContextResource 4276
#define sipName_OpenGLContextResource &sipStrings_QtQuick[4276]
#define sipNameNr_4298 4298
#define sipName_4298 &sipStrings_QtQuick[4298]
#define sipNameNr_QSGTexture__Filtering 4320
#define sipName_QSGTexture__Filtering &sipStrings_QtQuick[4320]
#define sipNameNr_ShaderCompilationType 727
#define sipName_ShaderCompilationType &sipStrings_QtQuick[727]
#define sipNameNr_baselineOffsetChanged 4342
#define sipName_baselineOffsetChanged &sipStrings_QtQuick[4342]
#define sipNameNr_beginExternalCommands 4364
#define sipName_beginExternalCommands &sipStrings_QtQuick[4364]
#define sipNameNr_childMouseEventFilter 4386
#define sipName_childMouseEventFilter &sipStrings_QtQuick[4386]
#define sipNameNr_graphicsConfiguration 4408
#define sipName_graphicsConfiguration &sipStrings_QtQuick[4408]
#define sipNameNr_hasDefaultAlphaBuffer 4430
#define sipName_hasDefaultAlphaBuffer &sipStrings_QtQuick[4430]
#define sipNameNr_implicitHeightChanged 4452
#define sipName_implicitHeightChanged &sipStrings_QtQuick[4452]
#define sipNameNr_insertChildNodeBefore 4474
#define sipName_insertChildNodeBefore &sipStrings_QtQuick[4474]
#define sipNameNr_isDebugMarkersEnabled 4496
#define sipName_isDebugMarkersEnabled &sipStrings_QtQuick[4496]
#define sipNameNr_mouseDoubleClickEvent 4518
#define sipName_mouseDoubleClickEvent &sipStrings_QtQuick[4518]
#define sipNameNr_pipelineCacheLoadFile 4540
#define sipName_pipelineCacheLoadFile &sipStrings_QtQuick[4540]
#define sipNameNr_pipelineCacheSaveFile 4562
#define sipName_pipelineCacheSaveFile &sipStrings_QtQuick[4562]
#define sipNameNr_prefersSoftwareDevice 4584
#define sipName_prefersSoftwareDevice &sipStrings_QtQuick[4584]
#define sipNameNr_sceneGraphAboutToStop 4606
#define sipName_sceneGraphAboutToStop &sipStrings_QtQuick[4606]
#define sipNameNr_sceneGraphInitialized 4628
#define sipName_sceneGraphInitialized &sipStrings_QtQuick[4628]
#define sipNameNr_sceneGraphInvalidated 4650
#define sipName_sceneGraphInvalidated &sipStrings_QtQuick[4650]
#define sipNameNr_setDefaultAlphaBuffer 4672
#define sipName_setDefaultAlphaBuffer &sipStrings_QtQuick[4672]
#define sipNameNr_setHorizontalWrapMode 4694
#define sipName_setHorizontalWrapMode &sipStrings_QtQuick[4694]
#define sipNameNr_setPersistentGraphics 4716
#define sipName_setPersistentGraphics &sipStrings_QtQuick[4716]
#define sipNameNr_setSelectionTextColor 4738
#define sipName_setSelectionTextColor &sipStrings_QtQuick[4738]
#define sipNameNr_shaderCompilationType 4760
#define sipName_shaderCompilationType &sipStrings_QtQuick[4760]
#define sipNameNr_BeforeRenderingStage 4782
#define sipName_BeforeRenderingStage &sipStrings_QtQuick[4782]
#define sipNameNr_BoundedRectRendering 4803
#define sipName_BoundedRectRendering &sipStrings_QtQuick[4803]
#define sipNameNr_CommandQueueResource 4824
#define sipName_CommandQueueResource &sipStrings_QtQuick[4824]
#define sipNameNr_ItemChildAddedChange 4845
#define sipName_ItemChildAddedChange &sipStrings_QtQuick[4845]
#define sipNameNr_ItemObservesViewport 4866
#define sipName_ItemObservesViewport &sipStrings_QtQuick[4866]
#define sipNameNr_ItemParentHasChanged 4887
#define sipName_ItemParentHasChanged &sipStrings_QtQuick[4887]
#define sipNameNr_QQuickGraphicsDevice 4908
#define sipName_QQuickGraphicsDevice &sipStrings_QtQuick[4908]
#define sipNameNr_QQuickItemGrabResult 4929
#define sipName_QQuickItemGrabResult &sipStrings_QtQuick[4929]
#define sipNameNr_QQuickTextureFactory 4950
#define sipName_QQuickTextureFactory &sipStrings_QtQuick[4950]
#define sipNameNr_QSGBasicGeometryNode 4971
#define sipName_QSGBasicGeometryNode &sipStrings_QtQuick[4971]
#define sipNameNr_QSGFlatColorMaterial 4992
#define sipName_QSGFlatColorMaterial &sipStrings_QtQuick[4992]
#define sipNameNr_QSGGeometry__Point2D 5013
#define sipName_QSGGeometry__Point2D &sipStrings_QtQuick[5013]
#define sipNameNr_QSGRendererInterface 5034
#define sipName_QSGRendererInterface &sipStrings_QtQuick[5034]
#define sipNameNr_QSGSimpleTextureNode 5055
#define sipName_QSGSimpleTextureNode &sipStrings_QtQuick[5055]
#define sipNameNr_QSGTexture__WrapMode 5076
#define sipName_QSGTexture__WrapMode &sipStrings_QtQuick[5076]
#define sipNameNr_RhiSwapchainResource 5097
#define sipName_RhiSwapchainResource &sipStrings_QtQuick[5097]
#define sipNameNr_SizeRootObjectToView 5118
#define sipName_SizeRootObjectToView &sipStrings_QtQuick[5118]
#define sipNameNr_SizeViewToRootObject 5139
#define sipName_SizeViewToRootObject &sipStrings_QtQuick[5139]
#define sipNameNr_TextureOwnsGLTexture 5160
#define sipName_TextureOwnsGLTexture &sipStrings_QtQuick[5160]
#define sipNameNr_acceptedMouseButtons 5181
#define sipName_acceptedMouseButtons &sipStrings_QtQuick[5181]
#define sipNameNr_contentsBoundingRect 5202
#define sipName_contentsBoundingRect &sipStrings_QtQuick[5202]
#define sipNameNr_contentsScaleChanged 5223
#define sipName_contentsScaleChanged &sipStrings_QtQuick[5223]
#define sipNameNr_implicitWidthChanged 5244
#define sipName_implicitWidthChanged &sipStrings_QtQuick[5244]
#define sipNameNr_incubationController 5265
#define sipName_incubationController &sipStrings_QtQuick[5265]
#define sipNameNr_insertChildNodeAfter 5286
#define sipName_insertChildNodeAfter &sipStrings_QtQuick[5286]
#define sipNameNr_isPersistentGraphics 5307
#define sipName_isPersistentGraphics &sipStrings_QtQuick[5307]
#define sipNameNr_nextItemInFocusChain 5328
#define sipName_nextItemInFocusChain &sipStrings_QtQuick[5328]
#define sipNameNr_requestImageResponse 5349
#define sipName_requestImageResponse &sipStrings_QtQuick[5349]
#define sipNameNr_separateBlendFactors 5370
#define sipName_separateBlendFactors &sipStrings_QtQuick[5370]
#define sipNameNr_setAcceptHoverEvents 5391
#define sipName_setAcceptHoverEvents &sipStrings_QtQuick[5391]
#define sipNameNr_setAcceptTouchEvents 5412
#define sipName_setAcceptTouchEvents &sipStrings_QtQuick[5412]
#define sipNameNr_setInitialProperties 5433
#define sipName_setInitialProperties &sipStrings_QtQuick[5433]
#define sipNameNr_setRenderTypeQuality 5454
#define sipName_setRenderTypeQuality &sipStrings_QtQuick[5454]
#define sipNameNr_setSceneGraphBackend 5475
#define sipName_setSceneGraphBackend &sipStrings_QtQuick[5475]
#define sipNameNr_setVertexDataPattern 5496
#define sipName_setVertexDataPattern &sipStrings_QtQuick[5496]
#define sipNameNr_AfterRenderingStage 5517
#define sipName_AfterRenderingStage &sipStrings_QtQuick[5517]
#define sipNameNr_AlwaysUploadPattern 5537
#define sipName_AlwaysUploadPattern &sipStrings_QtQuick[5537]
#define sipNameNr_CommandListResource 5557
#define sipName_CommandListResource &sipStrings_QtQuick[5557]
#define sipNameNr_ContextNotAvailable 5577
#define sipName_ContextNotAvailable &sipStrings_QtQuick[5577]
#define sipNameNr_CreateTextureOption 1112
#define sipName_CreateTextureOption &sipStrings_QtQuick[1112]
#define sipNameNr_DepthAwareRendering 5597
#define sipName_DepthAwareRendering &sipStrings_QtQuick[5597]
#define sipNameNr_ItemScaleHasChanged 5617
#define sipName_ItemScaleHasChanged &sipStrings_QtQuick[5617]
#define sipNameNr_NativeTextRendering 5637
#define sipName_NativeTextRendering &sipStrings_QtQuick[5637]
#define sipNameNr_QQuickImageProvider 5657
#define sipName_QQuickImageProvider &sipStrings_QtQuick[5657]
#define sipNameNr_QQuickImageResponse 5677
#define sipName_QQuickImageResponse &sipStrings_QtQuick[5677]
#define sipNameNr_QQuickRenderControl 5697
#define sipName_QQuickRenderControl &sipStrings_QtQuick[5697]
#define sipNameNr_RedirectPaintDevice 5717
#define sipName_RedirectPaintDevice &sipStrings_QtQuick[5717]
#define sipNameNr_RequiresDeterminant 5737
#define sipName_RequiresDeterminant &sipStrings_QtQuick[5737]
#define sipNameNr_UpdatePaintNodeData 1476
#define sipName_UpdatePaintNodeData &sipStrings_QtQuick[1476]
#define sipNameNr_antialiasingChanged 5757
#define sipName_antialiasingChanged &sipStrings_QtQuick[5757]
#define sipNameNr_beforeSynchronizing 5777
#define sipName_beforeSynchronizing &sipStrings_QtQuick[5777]
#define sipNameNr_childrenRectChanged 5797
#define sipName_childrenRectChanged &sipStrings_QtQuick[5797]
#define sipNameNr_contentsSizeChanged 5817
#define sipName_contentsSizeChanged &sipStrings_QtQuick[5817]
#define sipNameNr_createRectangleNode 5837
#define sipName_createRectangleNode &sipStrings_QtQuick[5837]
#define sipNameNr_endExternalCommands 5857
#define sipName_endExternalCommands &sipStrings_QtQuick[5857]
#define sipNameNr_isComponentComplete 5877
#define sipName_isComponentComplete &sipStrings_QtQuick[5877]
#define sipNameNr_isDebugLayerEnabled 5897
#define sipName_isDebugLayerEnabled &sipStrings_QtQuick[5897]
#define sipNameNr_markVertexDataDirty 5917
#define sipName_markVertexDataDirty &sipStrings_QtQuick[5917]
#define sipNameNr_removeAllChildNodes 5937
#define sipName_removeAllChildNodes &sipStrings_QtQuick[5937]
#define sipNameNr_renderTargetChanged 5957
#define sipName_renderTargetChanged &sipStrings_QtQuick[5957]
#define sipNameNr_setActiveFocusOnTab 5977
#define sipName_setActiveFocusOnTab &sipStrings_QtQuick[5977]
#define sipNameNr_setDepthBufferFor2D 5997
#define sipName_setDepthBufferFor2D &sipStrings_QtQuick[5997]
#define sipNameNr_setDeviceExtensions 6017
#define sipName_setDeviceExtensions &sipStrings_QtQuick[6017]
#define sipNameNr_setDevicePixelRatio 6037
#define sipName_setDevicePixelRatio &sipStrings_QtQuick[6037]
#define sipNameNr_setIndexDataPattern 6057
#define sipName_setIndexDataPattern &sipStrings_QtQuick[6057]
#define sipNameNr_setMirrorVertically 6077
#define sipName_setMirrorVertically &sipStrings_QtQuick[6077]
#define sipNameNr_setPerformanceHints 6097
#define sipName_setPerformanceHints &sipStrings_QtQuick[6097]
#define sipNameNr_setVerticalWrapMode 6117
#define sipName_setVerticalWrapMode &sipStrings_QtQuick[6117]
#define sipNameNr_textDocumentChanged 6137
#define sipName_textDocumentChanged &sipStrings_QtQuick[6137]
#define sipNameNr_vertexDataAsPoint2D 6157
#define sipName_vertexDataAsPoint2D &sipStrings_QtQuick[6157]
#define sipNameNr_ColorMaskComponent 173
#define sipName_ColorMaskComponent &sipStrings_QtQuick[173]
#define sipNameNr_CurveTextRendering 6177
#define sipName_CurveTextRendering &sipStrings_QtQuick[6177]
#define sipNameNr_MirrorHorizontally 6196
#define sipName_MirrorHorizontally &sipStrings_QtQuick[6196]
#define sipNameNr_MultisampleResolve 6215
#define sipName_MultisampleResolve &sipStrings_QtQuick[6215]
#define sipNameNr_OfflineCompilation 6234
#define sipName_OfflineCompilation &sipStrings_QtQuick[6234]
#define sipNameNr_OwnsOpaqueMaterial 6253
#define sipName_OwnsOpaqueMaterial &sipStrings_QtQuick[6253]
#define sipNameNr_6272 6272
#define sipName_6272 &sipStrings_QtQuick[6272]
#define sipNameNr_QQuickRenderTarget 6291
#define sipName_QQuickRenderTarget &sipStrings_QtQuick[6291]
#define sipNameNr_QQuickTextDocument 6310
#define sipName_QQuickTextDocument &sipStrings_QtQuick[6310]
#define sipNameNr_QQuickView__Status 6329
#define sipName_QQuickView__Status &sipStrings_QtQuick[6329]
#define sipNameNr_QSGTextureMaterial 6348
#define sipName_QSGTextureMaterial &sipStrings_QtQuick[6348]
#define sipNameNr_QSGTextureProvider 6367
#define sipName_QSGTextureProvider &sipStrings_QtQuick[6367]
#define sipNameNr_RenderPassResource 6386
#define sipName_RenderPassResource &sipStrings_QtQuick[6386]
#define sipNameNr_RequiresFullMatrix 6405
#define sipName_RequiresFullMatrix &sipStrings_QtQuick[6405]
#define sipNameNr_RuntimeCompilation 6424
#define sipName_RuntimeCompilation &sipStrings_QtQuick[6424]
#define sipNameNr_ShaderSourceString 6443
#define sipName_ShaderSourceString &sipStrings_QtQuick[6443]
#define sipNameNr_TexCoord1Attribute 6462
#define sipName_TexCoord1Attribute &sipStrings_QtQuick[6462]
#define sipNameNr_TexCoord2Attribute 6481
#define sipName_TexCoord2Attribute &sipStrings_QtQuick[6481]
#define sipNameNr_TextureCanUseAtlas 6500
#define sipName_TextureCanUseAtlas &sipStrings_QtQuick[6500]
#define sipNameNr_activeFocusChanged 6519
#define sipName_activeFocusChanged &sipStrings_QtQuick[6519]
#define sipNameNr_afterSynchronizing 6538
#define sipName_afterSynchronizing &sipStrings_QtQuick[6538]
#define sipNameNr_errorStringChanged 6557
#define sipName_errorStringChanged &sipStrings_QtQuick[6557]
#define sipNameNr_focusPolicyChanged 6576
#define sipName_focusPolicyChanged &sipStrings_QtQuick[6576]
#define sipNameNr_horizontalWrapMode 6595
#define sipName_horizontalWrapMode &sipStrings_QtQuick[6595]
#define sipNameNr_isVertexCoordinate 6614
#define sipName_isVertexCoordinate &sipStrings_QtQuick[6614]
#define sipNameNr_markIndexDataDirty 6633
#define sipName_markIndexDataDirty &sipStrings_QtQuick[6633]
#define sipNameNr_selectionTextColor 6652
#define sipName_selectionTextColor &sipStrings_QtQuick[6652]
#define sipNameNr_setAnisotropyLevel 6671
#define sipName_setAnisotropyLevel &sipStrings_QtQuick[6671]
#define sipNameNr_setContainmentMask 6690
#define sipName_setContainmentMask &sipStrings_QtQuick[6690]
#define sipNameNr_setMipmapFiltering 6709
#define sipName_setMipmapFiltering &sipStrings_QtQuick[6709]
#define sipNameNr_setPerformanceHint 6728
#define sipName_setPerformanceHint &sipStrings_QtQuick[6728]
#define sipNameNr_setTransformOrigin 6747
#define sipName_setTransformOrigin &sipStrings_QtQuick[6747]
#define sipNameNr_textureSizeChanged 6766
#define sipName_textureSizeChanged &sipStrings_QtQuick[6766]
#define sipNameNr_updateRectGeometry 6785
#define sipName_updateRectGeometry &sipStrings_QtQuick[6785]
#define sipNameNr_updateSampledImage 6804
#define sipName_updateSampledImage &sipStrings_QtQuick[6804]
#define sipNameNr_CustomCompileStep 6823
#define sipName_CustomCompileStep &sipStrings_QtQuick[6823]
#define sipNameNr_DrawTriangleStrip 6841
#define sipName_DrawTriangleStrip &sipStrings_QtQuick[6841]
#define sipNameNr_FramebufferObject 2043
#define sipName_FramebufferObject &sipStrings_QtQuick[2043]
#define sipNameNr_NonLocalFileError 6859
#define sipName_NonLocalFileError &sipStrings_QtQuick[6859]
#define sipNameNr_OneMinusSrc1Alpha 6877
#define sipName_OneMinusSrc1Alpha &sipStrings_QtQuick[6877]
#define sipNameNr_OneMinusSrc1Color 6895
#define sipName_OneMinusSrc1Color &sipStrings_QtQuick[6895]
#define sipNameNr_PositionAttribute 6913
#define sipName_PositionAttribute &sipStrings_QtQuick[6913]
#define sipNameNr_QQuickPaintedItem 6931
#define sipName_QQuickPaintedItem &sipStrings_QtQuick[6931]
#define sipNameNr_QSGDynamicTexture 6949
#define sipName_QSGDynamicTexture &sipStrings_QtQuick[6949]
#define sipNameNr_QSGGeometry__Type 6967
#define sipName_QSGGeometry__Type &sipStrings_QtQuick[6967]
#define sipNameNr_QSGMaterial__Flag 6985
#define sipName_QSGMaterial__Flag &sipStrings_QtQuick[6985]
#define sipNameNr_QSGMaterialShader 7003
#define sipName_QSGMaterialShader &sipStrings_QtQuick[7003]
#define sipNameNr_QSGNode__NodeType 7021
#define sipName_QSGNode__NodeType &sipStrings_QtQuick[7021]
#define sipNameNr_QSGSimpleRectNode 7039
#define sipName_QSGSimpleRectNode &sipStrings_QtQuick[7039]
#define sipNameNr_RenderTargetState 7057
#define sipName_RenderTargetState &sipStrings_QtQuick[7057]
#define sipNameNr_TexCoordAttribute 7075
#define sipName_TexCoordAttribute &sipStrings_QtQuick[7075]
#define sipNameNr_TextureHasMipmaps 7093
#define sipName_TextureHasMipmaps &sipStrings_QtQuick[7093]
#define sipNameNr_TransformNodeType 7111
#define sipName_TransformNodeType &sipStrings_QtQuick[7111]
#define sipNameNr_UnsignedShortType 7129
#define sipName_UnsignedShortType &sipStrings_QtQuick[7129]
#define sipNameNr_acceptHoverEvents 7147
#define sipName_acceptHoverEvents &sipStrings_QtQuick[7147]
#define sipNameNr_acceptTouchEvents 7165
#define sipName_acceptTouchEvents &sipStrings_QtQuick[7165]
#define sipNameNr_componentComplete 7183
#define sipName_componentComplete &sipStrings_QtQuick[7183]
#define sipNameNr_framebufferObject 7201
#define sipName_framebufferObject &sipStrings_QtQuick[7201]
#define sipNameNr_fromOpenGLContext 7219
#define sipName_fromOpenGLContext &sipStrings_QtQuick[7219]
#define sipNameNr_fromOpenGLTexture 7237
#define sipName_fromOpenGLTexture &sipStrings_QtQuick[7237]
#define sipNameNr_indexDataAsUShort 7255
#define sipName_indexDataAsUShort &sipStrings_QtQuick[7255]
#define sipNameNr_isTextureProvider 7273
#define sipName_isTextureProvider &sipStrings_QtQuick[7273]
#define sipNameNr_mouseReleaseEvent 7291
#define sipName_mouseReleaseEvent &sipStrings_QtQuick[7291]
#define sipNameNr_renderTypeQuality 7309
#define sipName_renderTypeQuality &sipStrings_QtQuick[7309]
#define sipNameNr_rendererInterface 7327
#define sipName_rendererInterface &sipStrings_QtQuick[7327]
#define sipNameNr_resetAntialiasing 7345
#define sipName_resetAntialiasing &sipStrings_QtQuick[7345]
#define sipNameNr_resetContentsSize 7363
#define sipName_resetContentsSize &sipStrings_QtQuick[7363]
#define sipNameNr_sceneGraphBackend 7381
#define sipName_sceneGraphBackend &sipStrings_QtQuick[7381]
#define sipNameNr_scheduleRenderJob 7399
#define sipName_scheduleRenderJob &sipStrings_QtQuick[7399]
#define sipNameNr_setBaselineOffset 7417
#define sipName_setBaselineOffset &sipStrings_QtQuick[7417]
#define sipNameNr_setGraphicsDevice 7435
#define sipName_setGraphicsDevice &sipStrings_QtQuick[7435]
#define sipNameNr_setImplicitHeight 7453
#define sipName_setImplicitHeight &sipStrings_QtQuick[7453]
#define sipNameNr_setOpaqueMaterial 7471
#define sipName_setOpaqueMaterial &sipStrings_QtQuick[7471]
#define sipNameNr_setOpaquePainting 7489
#define sipName_setOpaquePainting &sipStrings_QtQuick[7489]
#define sipNameNr_setSelectionColor 7507
#define sipName_setSelectionColor &sipStrings_QtQuick[7507]
#define sipNameNr_setShaderFileName 7525
#define sipName_setShaderFileName &sipStrings_QtQuick[7525]
#define sipNameNr_setTextRenderType 7543
#define sipName_setTextRenderType &sipStrings_QtQuick[7543]
#define sipNameNr_timestampsEnabled 7561
#define sipName_timestampsEnabled &sipStrings_QtQuick[7561]
#define sipNameNr_ungrabTouchPoints 7579
#define sipName_ungrabTouchPoints &sipStrings_QtQuick[7579]
#define sipNameNr_updateInputMethod 7597
#define sipName_updateInputMethod &sipStrings_QtQuick[7597]
#define sipNameNr_updateUniformData 7615
#define sipName_updateUniformData &sipStrings_QtQuick[7615]
#define sipNameNr_vertexDataPattern 7633
#define sipName_vertexDataPattern &sipStrings_QtQuick[7633]
#define sipNameNr_DirtyNodeRemoved 7651
#define sipName_DirtyNodeRemoved &sipStrings_QtQuick[7651]
#define sipNameNr_GeometryNodeType 7668
#define sipName_GeometryNodeType &sipStrings_QtQuick[7668]
#define sipNameNr_ItemAcceptsDrops 7685
#define sipName_ItemAcceptsDrops &sipStrings_QtQuick[7685]
#define sipNameNr_ItemIsFocusScope 7702
#define sipName_ItemIsFocusScope &sipStrings_QtQuick[7702]
#define sipNameNr_MirrorVertically 6080
#define sipName_MirrorVertically &sipStrings_QtQuick[6080]
#define sipNameNr_OneMinusDstAlpha 7719
#define sipName_OneMinusDstAlpha &sipStrings_QtQuick[7719]
#define sipNameNr_OneMinusDstColor 7736
#define sipName_OneMinusDstColor &sipStrings_QtQuick[7736]
#define sipNameNr_OneMinusSrcAlpha 7753
#define sipName_OneMinusSrcAlpha &sipStrings_QtQuick[7753]
#define sipNameNr_OneMinusSrcColor 7770
#define sipName_OneMinusSrcColor &sipStrings_QtQuick[7770]
#define sipNameNr_QNativeInterface 7787
#define sipName_QNativeInterface &sipStrings_QtQuick[7787]
#define sipNameNr_QQuickCloseEvent 7804
#define sipName_QQuickCloseEvent &sipStrings_QtQuick[7804]
#define sipNameNr_QQuickItem__Flag 7821
#define sipName_QQuickItem__Flag &sipStrings_QtQuick[7821]
#define sipNameNr_QSGOpenGLTexture 1012
#define sipName_QSGOpenGLTexture &sipStrings_QtQuick[1012]
#define sipNameNr_QSGRectangleNode 7838
#define sipName_QSGRectangleNode &sipStrings_QtQuick[7838]
#define sipNameNr_QSGTransformNode 7855
#define sipName_QSGTransformNode &sipStrings_QtQuick[7855]
#define sipNameNr_ShaderSourceFile 7872
#define sipName_ShaderSourceFile &sipStrings_QtQuick[7872]
#define sipNameNr_ShaderSourceType 940
#define sipName_ShaderSourceType &sipStrings_QtQuick[940]
#define sipNameNr_SrcAlphaSaturate 7889
#define sipName_SrcAlphaSaturate &sipStrings_QtQuick[7889]
#define sipNameNr_UnknownAttribute 7906
#define sipName_UnknownAttribute &sipStrings_QtQuick[7906]
#define sipNameNr_UnsignedByteType 7923
#define sipName_UnsignedByteType &sipStrings_QtQuick[7923]
#define sipNameNr_activeFocusOnTab 7940
#define sipName_activeFocusOnTab &sipStrings_QtQuick[7940]
#define sipNameNr_beforeFrameBegin 7957
#define sipName_beforeFrameBegin &sipStrings_QtQuick[7957]
#define sipNameNr_deviceExtensions 7974
#define sipName_deviceExtensions &sipStrings_QtQuick[7974]
#define sipNameNr_devicePixelRatio 7991
#define sipName_devicePixelRatio &sipStrings_QtQuick[7991]
#define sipNameNr_disconnectNotify 8008
#define sipName_disconnectNotify &sipStrings_QtQuick[8008]
#define sipNameNr_fillColorChanged 8025
#define sipName_fillColorChanged &sipStrings_QtQuick[8025]
#define sipNameNr_forceActiveFocus 8042
#define sipName_forceActiveFocus &sipStrings_QtQuick[8042]
#define sipNameNr_indexDataPattern 8059
#define sipName_indexDataPattern &sipStrings_QtQuick[8059]
#define sipNameNr_inheritedOpacity 8076
#define sipName_inheritedOpacity &sipStrings_QtQuick[8076]
#define sipNameNr_inputMethodEvent 8093
#define sipName_inputMethodEvent &sipStrings_QtQuick[8093]
#define sipNameNr_inputMethodQuery 8110
#define sipName_inputMethodQuery &sipStrings_QtQuick[8110]
#define sipNameNr_isSubtreeBlocked 8127
#define sipName_isSubtreeBlocked &sipStrings_QtQuick[8127]
#define sipNameNr_mapRectFromScene 8144
#define sipName_mapRectFromScene &sipStrings_QtQuick[8144]
#define sipNameNr_mirrorVertically 8161
#define sipName_mirrorVertically &sipStrings_QtQuick[8161]
#define sipNameNr_mouseGrabberItem 8178
#define sipName_mouseGrabberItem &sipStrings_QtQuick[8178]
#define sipNameNr_mouseUngrabEvent 8195
#define sipName_mouseUngrabEvent &sipStrings_QtQuick[8195]
#define sipNameNr_performanceHints 8212
#define sipName_performanceHints &sipStrings_QtQuick[8212]
#define sipNameNr_prependChildNode 8229
#define sipName_prependChildNode &sipStrings_QtQuick[8229]
#define sipNameNr_projectionMatrix 8246
#define sipName_projectionMatrix &sipStrings_QtQuick[8246]
#define sipNameNr_releaseResources 8263
#define sipName_releaseResources &sipStrings_QtQuick[8263]
#define sipNameNr_setContentsScale 8280
#define sipName_setContentsScale &sipStrings_QtQuick[8280]
#define sipNameNr_setImplicitWidth 8297
#define sipName_setImplicitWidth &sipStrings_QtQuick[8297]
#define sipNameNr_setIsRectangular 8314
#define sipName_setIsRectangular &sipStrings_QtQuick[8314]
#define sipNameNr_setKeepMouseGrab 8331
#define sipName_setKeepMouseGrab &sipStrings_QtQuick[8331]
#define sipNameNr_setKeepTouchGrab 8348
#define sipName_setKeepTouchGrab &sipStrings_QtQuick[8348]
#define sipNameNr_shaderSourceType 8365
#define sipName_shaderSourceType &sipStrings_QtQuick[8365]
#define sipNameNr_textureByteCount 8382
#define sipName_textureByteCount &sipStrings_QtQuick[8382]
#define sipNameNr_touchUngrabEvent 8399
#define sipName_touchUngrabEvent &sipStrings_QtQuick[8399]
#define sipNameNr_verticalWrapMode 8416
#define sipName_verticalWrapMode &sipStrings_QtQuick[8416]
#define sipNameNr_AnisotropyLevel 2017
#define sipName_AnisotropyLevel &sipStrings_QtQuick[2017]
#define sipNameNr_DrawTriangleFan 8433
#define sipName_DrawTriangleFan &sipStrings_QtQuick[8433]
#define sipNameNr_FastFBOResizing 8449
#define sipName_FastFBOResizing &sipStrings_QtQuick[8449]
#define sipNameNr_ItemHasContents 8465
#define sipName_ItemHasContents &sipStrings_QtQuick[8465]
#define sipNameNr_ItemSceneChange 8481
#define sipName_ItemSceneChange &sipStrings_QtQuick[8481]
#define sipNameNr_NativeRendering 8497
#define sipName_NativeRendering &sipStrings_QtQuick[8497]
#define sipNameNr_OpacityNodeType 8513
#define sipName_OpacityNodeType &sipStrings_QtQuick[8513]
#define sipNameNr_OpaqueRendering 8529
#define sipName_OpaqueRendering &sipStrings_QtQuick[8529]
#define sipNameNr_PainterResource 8545
#define sipName_PainterResource &sipStrings_QtQuick[8545]
#define sipNameNr_PerformanceHint 1048
#define sipName_PerformanceHint &sipStrings_QtQuick[1048]
#define sipNameNr_QSGGeometryNode 8561
#define sipName_QSGGeometryNode &sipStrings_QtQuick[8561]
#define sipNameNr_QSGMaterialType 8577
#define sipName_QSGMaterialType &sipStrings_QtQuick[8577]
#define sipNameNr_QtTextRendering 8593
#define sipName_QtTextRendering &sipStrings_QtQuick[8593]
#define sipNameNr_ReverseSubtract 8609
#define sipName_ReverseSubtract &sipStrings_QtQuick[8609]
#define sipNameNr_SceneGraphError 1729
#define sipName_SceneGraphError &sipStrings_QtQuick[1729]
#define sipNameNr_TextureIsOpaque 8625
#define sipName_TextureIsOpaque &sipStrings_QtQuick[8625]
#define sipNameNr_TexturedPoint2D 1218
#define sipName_TexturedPoint2D &sipStrings_QtQuick[1218]
#define sipNameNr_TransformOrigin 1961
#define sipName_TransformOrigin &sipStrings_QtQuick[1961]
#define sipNameNr_UnsignedIntType 8641
#define sipName_UnsignedIntType &sipStrings_QtQuick[8641]
#define sipNameNr_activeFocusItem 8657
#define sipName_activeFocusItem &sipStrings_QtQuick[8657]
#define sipNameNr_addTextDocument 8673
#define sipName_addTextDocument &sipStrings_QtQuick[8673]
#define sipNameNr_anisotropyLevel 8689
#define sipName_anisotropyLevel &sipStrings_QtQuick[8689]
#define sipNameNr_appendChildNode 8705
#define sipName_appendChildNode &sipStrings_QtQuick[8705]
#define sipNameNr_beforeRendering 8721
#define sipName_beforeRendering &sipStrings_QtQuick[8721]
#define sipNameNr_containmentMask 8737
#define sipName_containmentMask &sipStrings_QtQuick[8737]
#define sipNameNr_createImageNode 8753
#define sipName_createImageNode &sipStrings_QtQuick[8753]
#define sipNameNr_fromPaintDevice 8769
#define sipName_fromPaintDevice &sipStrings_QtQuick[8769]
#define sipNameNr_grabTouchPoints 7581
#define sipName_grabTouchPoints &sipStrings_QtQuick[7581]
#define sipNameNr_hasAlphaChannel 8785
#define sipName_hasAlphaChannel &sipStrings_QtQuick[8785]
#define sipNameNr_hoverEnterEvent 8801
#define sipName_hoverEnterEvent &sipStrings_QtQuick[8801]
#define sipNameNr_hoverLeaveEvent 8817
#define sipName_hoverLeaveEvent &sipStrings_QtQuick[8817]
#define sipNameNr_indexDataAsUInt 8833
#define sipName_indexDataAsUInt &sipStrings_QtQuick[8833]
#define sipNameNr_keyReleaseEvent 8849
#define sipName_keyReleaseEvent &sipStrings_QtQuick[8849]
#define sipNameNr_mapRectFromItem 8865
#define sipName_mapRectFromItem &sipStrings_QtQuick[8865]
#define sipNameNr_mipmapFiltering 8881
#define sipName_mipmapFiltering &sipStrings_QtQuick[8881]
#define sipNameNr_modelViewMatrix 8897
#define sipName_modelViewMatrix &sipStrings_QtQuick[8897]
#define sipNameNr_modifiedChanged 8913
#define sipName_modifiedChanged &sipStrings_QtQuick[8913]
#define sipNameNr_mousePressEvent 8929
#define sipName_mousePressEvent &sipStrings_QtQuick[8929]
#define sipNameNr_previousSibling 8945
#define sipName_previousSibling &sipStrings_QtQuick[8945]
#define sipNameNr_rebuildGeometry 8961
#define sipName_rebuildGeometry &sipStrings_QtQuick[8961]
#define sipNameNr_removeChildNode 8977
#define sipName_removeChildNode &sipStrings_QtQuick[8977]
#define sipNameNr_renderRequested 8993
#define sipName_renderRequested &sipStrings_QtQuick[8993]
#define sipNameNr_renderWindowFor 9009
#define sipName_renderWindowFor &sipStrings_QtQuick[9009]
#define sipNameNr_rotationChanged 9025
#define sipName_rotationChanged &sipStrings_QtQuick[9025]
#define sipNameNr_sceneGraphError 9041
#define sipName_sceneGraphError &sipStrings_QtQuick[9041]
#define sipNameNr_scopedFocusItem 9057
#define sipName_scopedFocusItem &sipStrings_QtQuick[9057]
#define sipNameNr_setAntialiasing 7347
#define sipName_setAntialiasing &sipStrings_QtQuick[7347]
#define sipNameNr_setContentsSize 7365
#define sipName_setContentsSize &sipStrings_QtQuick[7365]
#define sipNameNr_setDebugMarkers 9073
#define sipName_setDebugMarkers &sipStrings_QtQuick[9073]
#define sipNameNr_setRenderTarget 9089
#define sipName_setRenderTarget &sipStrings_QtQuick[9089]
#define sipNameNr_setTextDocument 9105
#define sipName_setTextDocument &sipStrings_QtQuick[9105]
#define sipNameNr_textureProvider 9121
#define sipName_textureProvider &sipStrings_QtQuick[9121]
#define sipNameNr_transformOrigin 9137
#define sipName_transformOrigin &sipStrings_QtQuick[9137]
#define sipNameNr_updatePaintNode 9153
#define sipName_updatePaintNode &sipStrings_QtQuick[9153]
#define sipNameNr_AfterSwapStage 9169
#define sipName_AfterSwapStage &sipStrings_QtQuick[9169]
#define sipNameNr_AnisotropyNone 9184
#define sipName_AnisotropyNone &sipStrings_QtQuick[9184]
#define sipNameNr_ColorAttribute 9199
#define sipName_ColorAttribute &sipStrings_QtQuick[9199]
#define sipNameNr_ColoredPoint2D 1417
#define sipName_ColoredPoint2D &sipStrings_QtQuick[1417]
#define sipNameNr_CurveRendering 9214
#define sipName_CurveRendering &sipStrings_QtQuick[9214]
#define sipNameNr_DeviceResource 3738
#define sipName_DeviceResource &sipStrings_QtQuick[3738]
#define sipNameNr_DirtyNodeAdded 9229
#define sipName_DirtyNodeAdded &sipStrings_QtQuick[9229]
#define sipNameNr_DynamicPattern 9244
#define sipName_DynamicPattern &sipStrings_QtQuick[9244]
#define sipNameNr_ItemChangeData 2266
#define sipName_ItemChangeData &sipStrings_QtQuick[2266]
#define sipNameNr_ItemIsViewport 9259
#define sipName_ItemIsViewport &sipStrings_QtQuick[9259]
#define sipNameNr_MirroredRepeat 9274
#define sipName_MirroredRepeat &sipStrings_QtQuick[9274]
#define sipNameNr_QSGOpacityNode 9289
#define sipName_QSGOpacityNode &sipStrings_QtQuick[9289]
#define sipNameNr_ShaderByteCode 9304
#define sipName_ShaderByteCode &sipStrings_QtQuick[9304]
#define sipNameNr_TextRenderType 1819
#define sipName_TextRenderType &sipStrings_QtQuick[1819]
#define sipNameNr_afterAnimating 9319
#define sipName_afterAnimating &sipStrings_QtQuick[9319]
#define sipNameNr_afterRendering 9334
#define sipName_afterRendering &sipStrings_QtQuick[9334]
#define sipNameNr_attributeCount 9349
#define sipName_attributeCount &sipStrings_QtQuick[9349]
#define sipNameNr_baselineOffset 9364
#define sipName_baselineOffset &sipStrings_QtQuick[9364]
#define sipNameNr_combinedMatrix 9379
#define sipName_combinedMatrix &sipStrings_QtQuick[9379]
#define sipNameNr_createRenderer 9394
#define sipName_createRenderer &sipStrings_QtQuick[9394]
#define sipNameNr_createTextNode 9409
#define sipName_createTextNode &sipStrings_QtQuick[9409]
#define sipNameNr_dragEnterEvent 9424
#define sipName_dragEnterEvent &sipStrings_QtQuick[9424]
#define sipNameNr_dragLeaveEvent 9439
#define sipName_dragLeaveEvent &sipStrings_QtQuick[9439]
#define sipNameNr_enabledChanged 9454
#define sipName_enabledChanged &sipStrings_QtQuick[9454]
#define sipNameNr_ensurePolished 9469
#define sipName_ensurePolished &sipStrings_QtQuick[9469]
#define sipNameNr_geometryChange 9484
#define sipName_geometryChange &sipStrings_QtQuick[9484]
#define sipNameNr_graphicsDevice 9499
#define sipName_graphicsDevice &sipStrings_QtQuick[9499]
#define sipNameNr_hasActiveFocus 9514
#define sipName_hasActiveFocus &sipStrings_QtQuick[9514]
#define sipNameNr_hoverMoveEvent 9529
#define sipName_hoverMoveEvent &sipStrings_QtQuick[9529]
#define sipNameNr_implicitHeight 9544
#define sipName_implicitHeight &sipStrings_QtQuick[9544]
#define sipNameNr_isAtlasTexture 9559
#define sipName_isAtlasTexture &sipStrings_QtQuick[9559]
#define sipNameNr_isOpacityDirty 9574
#define sipName_isOpacityDirty &sipStrings_QtQuick[9574]
#define sipNameNr_loadFromModule 9589
#define sipName_loadFromModule &sipStrings_QtQuick[9589]
#define sipNameNr_mapRectToScene 9604
#define sipName_mapRectToScene &sipStrings_QtQuick[9604]
#define sipNameNr_mouseMoveEvent 9619
#define sipName_mouseMoveEvent &sipStrings_QtQuick[9619]
#define sipNameNr_opacityChanged 9634
#define sipName_opacityChanged &sipStrings_QtQuick[9634]
#define sipNameNr_opaqueMaterial 9649
#define sipName_opaqueMaterial &sipStrings_QtQuick[9649]
#define sipNameNr_opaquePainting 9664
#define sipName_opaquePainting &sipStrings_QtQuick[9664]
#define sipNameNr_requestTexture 9679
#define sipName_requestTexture &sipStrings_QtQuick[9679]
#define sipNameNr_scissorEnabled 9694
#define sipName_scissorEnabled &sipStrings_QtQuick[9694]
#define sipNameNr_selectionColor 9709
#define sipName_selectionColor &sipStrings_QtQuick[9709]
#define sipNameNr_selectionCount 9724
#define sipName_selectionCount &sipStrings_QtQuick[9724]
#define sipNameNr_selectionStart 9739
#define sipName_selectionStart &sipStrings_QtQuick[9739]
#define sipNameNr_setDrawingMode 9754
#define sipName_setDrawingMode &sipStrings_QtQuick[9754]
#define sipNameNr_setFocusPolicy 9769
#define sipName_setFocusPolicy &sipStrings_QtQuick[9769]
#define sipNameNr_setGraphicsApi 9784
#define sipName_setGraphicsApi &sipStrings_QtQuick[9784]
#define sipNameNr_setOwnsTexture 9799
#define sipName_setOwnsTexture &sipStrings_QtQuick[9799]
#define sipNameNr_setTextureSize 9814
#define sipName_setTextureSize &sipStrings_QtQuick[9814]
#define sipNameNr_setVertexCount 9829
#define sipName_setVertexCount &sipStrings_QtQuick[9829]
#define sipNameNr_stencilEnabled 9844
#define sipName_stencilEnabled &sipStrings_QtQuick[9844]
#define sipNameNr_textRenderType 9859
#define sipName_textRenderType &sipStrings_QtQuick[9859]
#define sipNameNr_textureChanged 9874
#define sipName_textureChanged &sipStrings_QtQuick[9874]
#define sipNameNr_textureFactory 9889
#define sipName_textureFactory &sipStrings_QtQuick[9889]
#define sipNameNr_visibleChanged 9904
#define sipName_visibleChanged &sipStrings_QtQuick[9904]
#define sipNameNr_Anisotropy16x 9919
#define sipName_Anisotropy16x &sipStrings_QtQuick[9919]
#define sipNameNr_AttributeType 2321
#define sipName_AttributeType &sipStrings_QtQuick[2321]
#define sipNameNr_BasicNodeType 9933
#define sipName_BasicNodeType &sipStrings_QtQuick[9933]
#define sipNameNr_ConstantAlpha 4240
#define sipName_ConstantAlpha &sipStrings_QtQuick[4240]
#define sipNameNr_ConstantColor 4262
#define sipName_ConstantColor &sipStrings_QtQuick[4262]
#define sipNameNr_Direct3D11Rhi 9947
#define sipName_Direct3D11Rhi &sipStrings_QtQuick[9947]
#define sipNameNr_DirtyGeometry 9961
#define sipName_DirtyGeometry &sipStrings_QtQuick[9961]
#define sipNameNr_DirtyMaterial 9975
#define sipName_DirtyMaterial &sipStrings_QtQuick[9975]
#define sipNameNr_DirtyStateBit 3831
#define sipName_DirtyStateBit &sipStrings_QtQuick[3831]
#define sipNameNr_DrawLineStrip 9989
#define sipName_DrawLineStrip &sipStrings_QtQuick[9989]
#define sipNameNr_DrawTriangles 10003
#define sipName_DrawTriangles &sipStrings_QtQuick[10003]
#define sipNameNr_FragmentStage 10017
#define sipName_FragmentStage &sipStrings_QtQuick[10017]
#define sipNameNr_OwnedByParent 10031
#define sipName_OwnedByParent &sipStrings_QtQuick[10031]
#define sipNameNr_PyQt6_QtQuick 10045
#define sipName_PyQt6_QtQuick &sipStrings_QtQuick[10045]
#define sipNameNr_QSGNode__Flag 10059
#define sipName_QSGNode__Flag &sipStrings_QtQuick[10059]
#define sipNameNr_QSGRenderNode 10073
#define sipName_QSGRenderNode &sipStrings_QtQuick[10073]
#define sipNameNr_RenderingFlag 1878
#define sipName_RenderingFlag &sipStrings_QtQuick[1878]
#define sipNameNr_StaticPattern 10087
#define sipName_StaticPattern &sipStrings_QtQuick[10087]
#define sipNameNr_StreamPattern 10101
#define sipName_StreamPattern &sipStrings_QtQuick[10101]
#define sipNameNr_UsePreprocess 10115
#define sipName_UsePreprocess &sipStrings_QtQuick[10115]
#define sipNameNr_ViewportState 10129
#define sipName_ViewportState &sipStrings_QtQuick[10129]
#define sipNameNr_addTextLayout 10143
#define sipName_addTextLayout &sipStrings_QtQuick[10143]
#define sipNameNr_afterFrameEnd 10157
#define sipName_afterFrameEnd &sipStrings_QtQuick[10157]
#define sipNameNr_attributeType 10171
#define sipName_attributeType &sipStrings_QtQuick[10171]
#define sipNameNr_blendConstant 10185
#define sipName_blendConstant &sipStrings_QtQuick[10185]
#define sipNameNr_changedStates 10199
#define sipName_changedStates &sipStrings_QtQuick[10199]
#define sipNameNr_comparisonKey 10213
#define sipName_comparisonKey &sipStrings_QtQuick[10213]
#define sipNameNr_connectNotify 8011
#define sipName_connectNotify &sipStrings_QtQuick[8011]
#define sipNameNr_contentsScale 10227
#define sipName_contentsScale &sipStrings_QtQuick[10227]
#define sipNameNr_createTexture 10241
#define sipName_createTexture &sipStrings_QtQuick[10241]
#define sipNameNr_dragMoveEvent 10255
#define sipName_dragMoveEvent &sipStrings_QtQuick[10255]
#define sipNameNr_focusOutEvent 10269
#define sipName_focusOutEvent &sipStrings_QtQuick[10269]
#define sipNameNr_heightChanged 10283
#define sipName_heightChanged &sipStrings_QtQuick[10283]
#define sipNameNr_implicitWidth 10297
#define sipName_implicitWidth &sipStrings_QtQuick[10297]
#define sipNameNr_isApiRhiBased 10311
#define sipName_isApiRhiBased &sipStrings_QtQuick[10311]
#define sipNameNr_isMatrixDirty 10325
#define sipName_isMatrixDirty &sipStrings_QtQuick[10325]
#define sipNameNr_isRectangular 10339
#define sipName_isRectangular &sipStrings_QtQuick[10339]
#define sipNameNr_keepMouseGrab 10353
#define sipName_keepMouseGrab &sipStrings_QtQuick[10353]
#define sipNameNr_keepTouchGrab 10367
#define sipName_keepTouchGrab &sipStrings_QtQuick[10367]
#define sipNameNr_keyPressEvent 10381
#define sipName_keyPressEvent &sipStrings_QtQuick[10381]
#define sipNameNr_mapFromGlobal 10395
#define sipName_mapFromGlobal &sipStrings_QtQuick[10395]
#define sipNameNr_mapRectToItem 10409
#define sipName_mapRectToItem &sipStrings_QtQuick[10409]
#define sipNameNr_nativeTexture 10423
#define sipName_nativeTexture &sipStrings_QtQuick[10423]
#define sipNameNr_parentChanged 10437
#define sipName_parentChanged &sipStrings_QtQuick[10437]
#define sipNameNr_prepareThread 10451
#define sipName_prepareThread &sipStrings_QtQuick[10451]
#define sipNameNr_requestPixmap 10465
#define sipName_requestPixmap &sipStrings_QtQuick[10465]
#define sipNameNr_setDebugLayer 10479
#define sipName_setDebugLayer &sipStrings_QtQuick[10479]
#define sipNameNr_setIndexCount 10493
#define sipName_setIndexCount &sipStrings_QtQuick[10493]
#define sipNameNr_setParentItem 10507
#define sipName_setParentItem &sipStrings_QtQuick[10507]
#define sipNameNr_setRenderType 10521
#define sipName_setRenderType &sipStrings_QtQuick[10521]
#define sipNameNr_setResizeMode 10535
#define sipName_setResizeMode &sipStrings_QtQuick[10535]
#define sipNameNr_setSourceRect 10549
#define sipName_setSourceRect &sipStrings_QtQuick[10549]
#define sipNameNr_setStyleColor 10563
#define sipName_setStyleColor &sipStrings_QtQuick[10563]
#define sipNameNr_setTimestamps 10577
#define sipName_setTimestamps &sipStrings_QtQuick[10577]
#define sipNameNr_smoothChanged 10591
#define sipName_smoothChanged &sipStrings_QtQuick[10591]
#define sipNameNr_sourceChanged 10605
#define sipName_sourceChanged &sipStrings_QtQuick[10605]
#define sipNameNr_statusChanged 10619
#define sipName_statusChanged &sipStrings_QtQuick[10619]
#define sipNameNr_transformNode 10633
#define sipName_transformNode &sipStrings_QtQuick[10633]
#define sipNameNr_updateTexture 10647
#define sipName_updateTexture &sipStrings_QtQuick[10647]
#define sipNameNr_windowChanged 10661
#define sipName_windowChanged &sipStrings_QtQuick[10661]
#define sipNameNr_Anisotropy2x 10675
#define sipName_Anisotropy2x &sipStrings_QtQuick[10675]
#define sipNameNr_Anisotropy4x 10688
#define sipName_Anisotropy4x &sipStrings_QtQuick[10688]
#define sipNameNr_Anisotropy8x 10701
#define sipName_Anisotropy8x &sipStrings_QtQuick[10701]
#define sipNameNr_AttributeSet 2534
#define sipName_AttributeSet &sipStrings_QtQuick[2534]
#define sipNameNr_ClipNodeType 10714
#define sipName_ClipNodeType &sipStrings_QtQuick[10714]
#define sipNameNr_DirtyOpacity 10727
#define sipName_DirtyOpacity &sipStrings_QtQuick[10727]
#define sipNameNr_DrawLineLoop 10740
#define sipName_DrawLineLoop &sipStrings_QtQuick[10740]
#define sipNameNr_OwnsGeometry 10753
#define sipName_OwnsGeometry &sipStrings_QtQuick[10753]
#define sipNameNr_OwnsMaterial 10766
#define sipName_OwnsMaterial &sipStrings_QtQuick[10766]
#define sipNameNr_QQuickWindow 10779
#define sipName_QQuickWindow &sipStrings_QtQuick[10779]
#define sipNameNr_QSGImageNode 10792
#define sipName_QSGImageNode &sipStrings_QtQuick[10792]
#define sipNameNr_RenderMode2D 10805
#define sipName_RenderMode2D &sipStrings_QtQuick[10805]
#define sipNameNr_RenderMode3D 10818
#define sipName_RenderMode3D &sipStrings_QtQuick[10818]
#define sipNameNr_RenderTarget 1515
#define sipName_RenderTarget &sipStrings_QtQuick[1515]
#define sipNameNr_ScissorState 10831
#define sipName_ScissorState &sipStrings_QtQuick[10831]
#define sipNameNr_StencilState 10844
#define sipName_StencilState &sipStrings_QtQuick[10844]
#define sipNameNr_antialiasing 10857
#define sipName_antialiasing &sipStrings_QtQuick[10857]
#define sipNameNr_childAtIndex 10870
#define sipName_childAtIndex &sipStrings_QtQuick[10870]
#define sipNameNr_childrenRect 10883
#define sipName_childrenRect &sipStrings_QtQuick[10883]
#define sipNameNr_colorChanged 10896
#define sipName_colorChanged &sipStrings_QtQuick[10896]
#define sipNameNr_contentsSize 10909
#define sipName_contentsSize &sipStrings_QtQuick[10909]
#define sipNameNr_createShader 10922
#define sipName_createShader &sipStrings_QtQuick[10922]
#define sipNameNr_dumpItemTree 10935
#define sipName_dumpItemTree &sipStrings_QtQuick[10935]
#define sipNameNr_focusChanged 10948
#define sipName_focusChanged &sipStrings_QtQuick[10948]
#define sipNameNr_focusInEvent 10961
#define sipName_focusInEvent &sipStrings_QtQuick[10961]
#define sipNameNr_frameSwapped 10974
#define sipName_frameSwapped &sipStrings_QtQuick[10974]
#define sipNameNr_isAncestorOf 10987
#define sipName_isAncestorOf &sipStrings_QtQuick[10987]
#define sipNameNr_isFocusScope 11000
#define sipName_isFocusScope &sipStrings_QtQuick[11000]
#define sipNameNr_mapFromScene 11013
#define sipName_mapFromScene &sipStrings_QtQuick[11013]
#define sipNameNr_renderTarget 11026
#define sipName_renderTarget &sipStrings_QtQuick[11026]
#define sipNameNr_renderWindow 11039
#define sipName_renderWindow &sipStrings_QtQuick[11039]
#define sipNameNr_requestImage 11052
#define sipName_requestImage &sipStrings_QtQuick[11052]
#define sipNameNr_scaleChanged 11065
#define sipName_scaleChanged &sipStrings_QtQuick[11065]
#define sipNameNr_sceneChanged 11078
#define sipName_sceneChanged &sipStrings_QtQuick[11078]
#define sipNameNr_setFillColor 11091
#define sipName_setFillColor &sipStrings_QtQuick[11091]
#define sipNameNr_setFiltering 11104
#define sipName_setFiltering &sipStrings_QtQuick[11104]
#define sipNameNr_setLineWidth 11117
#define sipName_setLineWidth &sipStrings_QtQuick[11117]
#define sipNameNr_setLinkColor 11130
#define sipName_setLinkColor &sipStrings_QtQuick[11130]
#define sipNameNr_setTextStyle 11143
#define sipName_setTextStyle &sipStrings_QtQuick[11143]
#define sipNameNr_sizeOfVertex 11156
#define sipName_sizeOfVertex &sipStrings_QtQuick[11156]
#define sipNameNr_stateChanged 11169
#define sipName_stateChanged &sipStrings_QtQuick[11169]
#define sipNameNr_stencilValue 11182
#define sipName_stencilValue &sipStrings_QtQuick[11182]
#define sipNameNr_textDocument 11195
#define sipName_textDocument &sipStrings_QtQuick[11195]
#define sipNameNr_updatePolish 11208
#define sipName_updatePolish &sipStrings_QtQuick[11208]
#define sipNameNr_viewportItem 11221
#define sipName_viewportItem &sipStrings_QtQuick[11221]
#define sipNameNr_viewportRect 11234
#define sipName_viewportRect &sipStrings_QtQuick[11234]
#define sipNameNr_widthChanged 11247
#define sipName_widthChanged &sipStrings_QtQuick[11247]
#define sipNameNr_BlendFactor 288
#define sipName_BlendFactor &sipStrings_QtQuick[288]
#define sipNameNr_BottomRight 11260
#define sipName_BottomRight &sipStrings_QtQuick[11260]
#define sipNameNr_ClampToEdge 11272
#define sipName_ClampToEdge &sipStrings_QtQuick[11272]
#define sipNameNr_DataPattern 2944
#define sipName_DataPattern &sipStrings_QtQuick[2944]
#define sipNameNr_DirtyMatrix 11284
#define sipName_DirtyMatrix &sipStrings_QtQuick[11284]
#define sipNameNr_DrawingMode 2969
#define sipName_DrawingMode &sipStrings_QtQuick[2969]
#define sipNameNr_GraphicsApi 1154
#define sipName_GraphicsApi &sipStrings_QtQuick[1154]
#define sipNameNr_NoTransform 11296
#define sipName_NoTransform &sipStrings_QtQuick[11296]
#define sipNameNr_PolygonMode 342
#define sipName_PolygonMode &sipStrings_QtQuick[342]
#define sipNameNr_QSGClipNode 11308
#define sipName_QSGClipNode &sipStrings_QtQuick[11308]
#define sipNameNr_QSGGeometry 11320
#define sipName_QSGGeometry &sipStrings_QtQuick[11320]
#define sipNameNr_QSGMaterial 11332
#define sipName_QSGMaterial &sipStrings_QtQuick[11332]
#define sipNameNr_QSGTextNode 11344
#define sipName_QSGTextNode &sipStrings_QtQuick[11344]
#define sipNameNr_QtRendering 11356
#define sipName_QtRendering &sipStrings_QtQuick[11356]
#define sipNameNr_RenderStage 2509
#define sipName_RenderStage &sipStrings_QtQuick[2509]
#define sipNameNr_RenderState 1641
#define sipName_RenderState &sipStrings_QtQuick[1641]
#define sipNameNr_RhiResource 11368
#define sipName_RhiResource &sipStrings_QtQuick[11368]
#define sipNameNr_VertexStage 11380
#define sipName_VertexStage &sipStrings_QtQuick[11380]
#define sipNameNr_blendEnable 11392
#define sipName_blendEnable &sipStrings_QtQuick[11392]
#define sipNameNr_clipChanged 11404
#define sipName_clipChanged &sipStrings_QtQuick[11404]
#define sipNameNr_contentItem 11416
#define sipName_contentItem &sipStrings_QtQuick[11416]
#define sipNameNr_customEvent 11428
#define sipName_customEvent &sipStrings_QtQuick[11428]
#define sipNameNr_determinant 11440
#define sipName_determinant &sipStrings_QtQuick[11440]
#define sipNameNr_dirtyStates 11452
#define sipName_dirtyStates &sipStrings_QtQuick[11452]
#define sipNameNr_drawingMode 11464
#define sipName_drawingMode &sipStrings_QtQuick[11464]
#define sipNameNr_errorString 11476
#define sipName_errorString &sipStrings_QtQuick[11476]
#define sipNameNr_eventFilter 11488
#define sipName_eventFilter &sipStrings_QtQuick[11488]
#define sipNameNr_exposeEvent 11500
#define sipName_exposeEvent &sipStrings_QtQuick[11500]
#define sipNameNr_focusObject 11512
#define sipName_focusObject &sipStrings_QtQuick[11512]
#define sipNameNr_focusPolicy 11524
#define sipName_focusPolicy &sipStrings_QtQuick[11524]
#define sipNameNr_getResource 11536
#define sipName_getResource &sipStrings_QtQuick[11536]
#define sipNameNr_grabToImage 11548
#define sipName_grabToImage &sipStrings_QtQuick[11548]
#define sipNameNr_graphicsApi 11560
#define sipName_graphicsApi &sipStrings_QtQuick[11560]
#define sipNameNr_heightValid 11572
#define sipName_heightValid &sipStrings_QtQuick[11572]
#define sipNameNr_initialSize 11584
#define sipName_initialSize &sipStrings_QtQuick[11584]
#define sipNameNr_mapFromItem 11596
#define sipName_mapFromItem &sipStrings_QtQuick[11596]
#define sipNameNr_mapToGlobal 11608
#define sipName_mapToGlobal &sipStrings_QtQuick[11608]
#define sipNameNr_nativeEvent 11620
#define sipName_nativeEvent &sipStrings_QtQuick[11620]
#define sipNameNr_nextSibling 11632
#define sipName_nextSibling &sipStrings_QtQuick[11632]
#define sipNameNr_ownsTexture 11644
#define sipName_ownsTexture &sipStrings_QtQuick[11644]
#define sipNameNr_polishItems 11656
#define sipName_polishItems &sipStrings_QtQuick[11656]
#define sipNameNr_polygonMode 11668
#define sipName_polygonMode &sipStrings_QtQuick[11668]
#define sipNameNr_resetHeight 11680
#define sipName_resetHeight &sipStrings_QtQuick[11680]
#define sipNameNr_resizeEvent 11692
#define sipName_resizeEvent &sipStrings_QtQuick[11692]
#define sipNameNr_rootContext 11704
#define sipName_rootContext &sipStrings_QtQuick[11704]
#define sipNameNr_sampleCount 11716
#define sipName_sampleCount &sipStrings_QtQuick[11716]
#define sipNameNr_scissorRect 11728
#define sipName_scissorRect &sipStrings_QtQuick[11728]
#define sipNameNr_setClipRect 11740
#define sipName_setClipRect &sipStrings_QtQuick[11740]
#define sipNameNr_setGeometry 11752
#define sipName_setGeometry &sipStrings_QtQuick[11752]
#define sipNameNr_setMaterial 11764
#define sipName_setMaterial &sipStrings_QtQuick[11764]
#define sipNameNr_setModified 11776
#define sipName_setModified &sipStrings_QtQuick[11776]
#define sipNameNr_setRotation 11788
#define sipName_setRotation &sipStrings_QtQuick[11788]
#define sipNameNr_setViewport 11800
#define sipName_setViewport &sipStrings_QtQuick[11800]
#define sipNameNr_sizeOfIndex 11812
#define sipName_sizeOfIndex &sipStrings_QtQuick[11812]
#define sipNameNr_stackBefore 11824
#define sipName_stackBefore &sipStrings_QtQuick[11824]
#define sipNameNr_surfaceType 11836
#define sipName_surfaceType &sipStrings_QtQuick[11836]
#define sipNameNr_synchronize 11848
#define sipName_synchronize &sipStrings_QtQuick[11848]
#define sipNameNr_tabletEvent 11860
#define sipName_tabletEvent &sipStrings_QtQuick[11860]
#define sipNameNr_textureSize 11872
#define sipName_textureSize &sipStrings_QtQuick[11872]
#define sipNameNr_ungrabMouse 11884
#define sipName_ungrabMouse &sipStrings_QtQuick[11884]
#define sipNameNr_uniformData 11896
#define sipName_uniformData &sipStrings_QtQuick[11896]
#define sipNameNr_unsetCursor 11908
#define sipName_unsetCursor &sipStrings_QtQuick[11908]
#define sipNameNr_vertexCount 11920
#define sipName_vertexCount &sipStrings_QtQuick[11920]
#define sipNameNr_BlendState 11932
#define sipName_BlendState &sipStrings_QtQuick[11932]
#define sipNameNr_BottomLeft 11943
#define sipName_BottomLeft &sipStrings_QtQuick[11943]
#define sipNameNr_Bytes2Type 11954
#define sipName_Bytes2Type &sipStrings_QtQuick[11954]
#define sipNameNr_Bytes3Type 11965
#define sipName_Bytes3Type &sipStrings_QtQuick[11965]
#define sipNameNr_Bytes4Type 11976
#define sipName_Bytes4Type &sipStrings_QtQuick[11976]
#define sipNameNr_ColorState 11987
#define sipName_ColorState &sipStrings_QtQuick[11987]
#define sipNameNr_DepthState 11998
#define sipName_DepthState &sipStrings_QtQuick[11998]
#define sipNameNr_Direct3D11 12009
#define sipName_Direct3D11 &sipStrings_QtQuick[12009]
#define sipNameNr_Direct3D12 12020
#define sipName_Direct3D12 &sipStrings_QtQuick[12020]
#define sipNameNr_DirtyState 824
#define sipName_DirtyState &sipStrings_QtQuick[824]
#define sipNameNr_DoubleType 12031
#define sipName_DoubleType &sipStrings_QtQuick[12031]
#define sipNameNr_DrawPoints 12042
#define sipName_DrawPoints &sipStrings_QtQuick[12042]
#define sipNameNr_ItemChange 3765
#define sipName_ItemChange &sipStrings_QtQuick[3765]
#define sipNameNr_NoBatching 12053
#define sipName_NoBatching &sipStrings_QtQuick[12053]
#define sipNameNr_QQuickItem 12064
#define sipName_QQuickItem &sipStrings_QtQuick[12064]
#define sipNameNr_QQuickView 12075
#define sipName_QQuickView &sipStrings_QtQuick[12075]
#define sipNameNr_QSGTexture 12086
#define sipName_QSGTexture &sipStrings_QtQuick[12086]
#define sipNameNr_RenderMode 1355
#define sipName_RenderMode &sipStrings_QtQuick[1355]
#define sipNameNr_RenderType 1823
#define sipName_RenderType &sipStrings_QtQuick[1823]
#define sipNameNr_ResizeMode 3788
#define sipName_ResizeMode &sipStrings_QtQuick[3788]
#define sipNameNr_ShaderType 1388
#define sipName_ShaderType &sipStrings_QtQuick[1388]
#define sipNameNr_WriteError 12097
#define sipName_WriteError &sipStrings_QtQuick[12097]
#define sipNameNr_attributes 12108
#define sipName_attributes &sipStrings_QtQuick[12108]
#define sipNameNr_beginFrame 12119
#define sipName_beginFrame &sipStrings_QtQuick[12119]
#define sipNameNr_childCount 12130
#define sipName_childCount &sipStrings_QtQuick[12130]
#define sipNameNr_childEvent 12141
#define sipName_childEvent &sipStrings_QtQuick[12141]
#define sipNameNr_childItems 12152
#define sipName_childItems &sipStrings_QtQuick[12152]
#define sipNameNr_classBegin 12163
#define sipName_classBegin &sipStrings_QtQuick[12163]
#define sipNameNr_clipRegion 12174
#define sipName_clipRegion &sipStrings_QtQuick[12174]
#define sipNameNr_closeEvent 12185
#define sipName_closeEvent &sipStrings_QtQuick[12185]
#define sipNameNr_colorWrite 12196
#define sipName_colorWrite &sipStrings_QtQuick[12196]
#define sipNameNr_deviceRect 12207
#define sipName_deviceRect &sipStrings_QtQuick[12207]
#define sipNameNr_firstChild 12218
#define sipName_firstChild &sipStrings_QtQuick[12218]
#define sipNameNr_fromNative 12229
#define sipName_fromNative &sipStrings_QtQuick[12229]
#define sipNameNr_grabWindow 12240
#define sipName_grabWindow &sipStrings_QtQuick[12240]
#define sipNameNr_hasMipmaps 12251
#define sipName_hasMipmaps &sipStrings_QtQuick[12251]
#define sipNameNr_indexCount 12262
#define sipName_indexCount &sipStrings_QtQuick[12262]
#define sipNameNr_initialize 12273
#define sipName_initialize &sipStrings_QtQuick[12273]
#define sipNameNr_invalidate 12284
#define sipName_invalidate &sipStrings_QtQuick[12284]
#define sipNameNr_isModified 12295
#define sipName_isModified &sipStrings_QtQuick[12295]
#define sipNameNr_isPosition 12306
#define sipName_isPosition &sipStrings_QtQuick[12306]
#define sipNameNr_itemChange 12317
#define sipName_itemChange &sipStrings_QtQuick[12317]
#define sipNameNr_mapToScene 12328
#define sipName_mapToScene &sipStrings_QtQuick[12328]
#define sipNameNr_paintEvent 12339
#define sipName_paintEvent &sipStrings_QtQuick[12339]
#define sipNameNr_parentItem 12350
#define sipName_parentItem &sipStrings_QtQuick[12350]
#define sipNameNr_preprocess 12361
#define sipName_preprocess &sipStrings_QtQuick[12361]
#define sipNameNr_renderType 12372
#define sipName_renderType &sipStrings_QtQuick[12372]
#define sipNameNr_resetWidth 12383
#define sipName_resetWidth &sipStrings_QtQuick[12383]
#define sipNameNr_resizeMode 12394
#define sipName_resizeMode &sipStrings_QtQuick[12394]
#define sipNameNr_rootObject 12405
#define sipName_rootObject &sipStrings_QtQuick[12405]
#define sipNameNr_saveToFile 12416
#define sipName_saveToFile &sipStrings_QtQuick[12416]
#define sipNameNr_setEnabled 12427
#define sipName_setEnabled &sipStrings_QtQuick[12427]
#define sipNameNr_setOpacity 12438
#define sipName_setOpacity &sipStrings_QtQuick[12438]
#define sipNameNr_setSamples 12449
#define sipName_setSamples &sipStrings_QtQuick[12449]
#define sipNameNr_setTexture 12460
#define sipName_setTexture &sipStrings_QtQuick[12460]
#define sipNameNr_setVisible 12471
#define sipName_setVisible &sipStrings_QtQuick[12471]
#define sipNameNr_shaderType 12482
#define sipName_shaderType &sipStrings_QtQuick[12482]
#define sipNameNr_sourceRect 12493
#define sipName_sourceRect &sipStrings_QtQuick[12493]
#define sipNameNr_stackAfter 12504
#define sipName_stackAfter &sipStrings_QtQuick[12504]
#define sipNameNr_styleColor 12515
#define sipName_styleColor &sipStrings_QtQuick[12515]
#define sipNameNr_targetSize 12526
#define sipName_targetSize &sipStrings_QtQuick[12526]
#define sipNameNr_timerEvent 12537
#define sipName_timerEvent &sipStrings_QtQuick[12537]
#define sipNameNr_touchEvent 12548
#define sipName_touchEvent &sipStrings_QtQuick[12548]
#define sipNameNr_vertexData 12559
#define sipName_vertexData &sipStrings_QtQuick[12559]
#define sipNameNr_wheelEvent 12570
#define sipName_wheelEvent &sipStrings_QtQuick[12570]
#define sipNameNr_widthValid 12581
#define sipName_widthValid &sipStrings_QtQuick[12581]
#define sipNameNr_Attribute 3812
#define sipName_Attribute &sipStrings_QtQuick[3812]
#define sipNameNr_CullFront 12592
#define sipName_CullFront &sipStrings_QtQuick[12592]
#define sipNameNr_CullState 12602
#define sipName_CullState &sipStrings_QtQuick[12602]
#define sipNameNr_DrawLines 12612
#define sipName_DrawLines &sipStrings_QtQuick[12612]
#define sipNameNr_Filtering 4332
#define sipName_Filtering &sipStrings_QtQuick[4332]
#define sipNameNr_FloatType 12622
#define sipName_FloatType &sipStrings_QtQuick[12622]
#define sipNameNr_OpenGLRhi 12632
#define sipName_OpenGLRhi &sipStrings_QtQuick[12632]
#define sipNameNr_ReadError 12642
#define sipName_ReadError &sipStrings_QtQuick[12642]
#define sipNameNr_RhiShader 12652
#define sipName_RhiShader &sipStrings_QtQuick[12652]
#define sipNameNr_ShortType 7137
#define sipName_ShortType &sipStrings_QtQuick[7137]
#define sipNameNr_Src1Alpha 6885
#define sipName_Src1Alpha &sipStrings_QtQuick[6885]
#define sipNameNr_Src1Color 6903
#define sipName_Src1Color &sipStrings_QtQuick[6903]
#define sipNameNr_StateFlag 3046
#define sipName_StateFlag &sipStrings_QtQuick[3046]
#define sipNameNr_TextStyle 3858
#define sipName_TextStyle &sipStrings_QtQuick[3858]
#define sipNameNr_VulkanRhi 12662
#define sipName_VulkanRhi &sipStrings_QtQuick[12662]
#define sipNameNr_boolValue 12672
#define sipName_boolValue &sipStrings_QtQuick[12672]
#define sipNameNr_dropEvent 12682
#define sipName_dropEvent &sipStrings_QtQuick[12682]
#define sipNameNr_fillColor 12692
#define sipName_fillColor &sipStrings_QtQuick[12692]
#define sipNameNr_filtering 12702
#define sipName_filtering &sipStrings_QtQuick[12702]
#define sipNameNr_grabMouse 11886
#define sipName_grabMouse &sipStrings_QtQuick[11886]
#define sipNameNr_hideEvent 12712
#define sipName_hideEvent &sipStrings_QtQuick[12712]
#define sipNameNr_imageType 12722
#define sipName_imageType &sipStrings_QtQuick[12722]
#define sipNameNr_indexData 12732
#define sipName_indexData &sipStrings_QtQuick[12732]
#define sipNameNr_indexType 12742
#define sipName_indexType &sipStrings_QtQuick[12742]
#define sipNameNr_isEnabled 12752
#define sipName_isEnabled &sipStrings_QtQuick[12752]
#define sipNameNr_isVisible 12762
#define sipName_isVisible &sipStrings_QtQuick[12762]
#define sipNameNr_lastChild 12772
#define sipName_lastChild &sipStrings_QtQuick[12772]
#define sipNameNr_lineCount 12782
#define sipName_lineCount &sipStrings_QtQuick[12782]
#define sipNameNr_lineStart 12792
#define sipName_lineStart &sipStrings_QtQuick[12792]
#define sipNameNr_lineWidth 12802
#define sipName_lineWidth &sipStrings_QtQuick[12802]
#define sipNameNr_linkColor 12812
#define sipName_linkColor &sipStrings_QtQuick[12812]
#define sipNameNr_mapToItem 12822
#define sipName_mapToItem &sipStrings_QtQuick[12822]
#define sipNameNr_markDirty 12832
#define sipName_markDirty &sipStrings_QtQuick[12832]
#define sipNameNr_moveEvent 12842
#define sipName_moveEvent &sipStrings_QtQuick[12842]
#define sipNameNr_realValue 12852
#define sipName_realValue &sipStrings_QtQuick[12852]
#define sipNameNr_setCursor 11910
#define sipName_setCursor &sipStrings_QtQuick[11910]
#define sipNameNr_setHeight 11682
#define sipName_setHeight &sipStrings_QtQuick[11682]
#define sipNameNr_setMatrix 12862
#define sipName_setMatrix &sipStrings_QtQuick[12862]
#define sipNameNr_setMipmap 12872
#define sipName_setMipmap &sipStrings_QtQuick[12872]
#define sipNameNr_setSmooth 12882
#define sipName_setSmooth &sipStrings_QtQuick[12882]
#define sipNameNr_setSource 12892
#define sipName_setSource &sipStrings_QtQuick[12892]
#define sipNameNr_showEvent 12902
#define sipName_showEvent &sipStrings_QtQuick[12902]
#define sipNameNr_textStyle 12912
#define sipName_textStyle &sipStrings_QtQuick[12912]
#define sipNameNr_tupleSize 12922
#define sipName_tupleSize &sipStrings_QtQuick[12922]
#define sipNameNr_viewCount 12932
#define sipName_viewCount &sipStrings_QtQuick[12932]
#define sipNameNr_Blending 12942
#define sipName_Blending &sipStrings_QtQuick[12942]
#define sipNameNr_ByteType 7931
#define sipName_ByteType &sipStrings_QtQuick[7931]
#define sipNameNr_CullBack 12951
#define sipName_CullBack &sipStrings_QtQuick[12951]
#define sipNameNr_CullMode 553
#define sipName_CullMode &sipStrings_QtQuick[553]
#define sipNameNr_CullNone 12960
#define sipName_CullNone &sipStrings_QtQuick[12960]
#define sipNameNr_DirtyAll 12969
#define sipName_DirtyAll &sipStrings_QtQuick[12969]
#define sipNameNr_DstAlpha 7727
#define sipName_DstAlpha &sipStrings_QtQuick[7727]
#define sipNameNr_DstColor 7744
#define sipName_DstColor &sipStrings_QtQuick[7744]
#define sipNameNr_MetalRhi 12978
#define sipName_MetalRhi &sipStrings_QtQuick[12978]
#define sipNameNr_NodeType 7030
#define sipName_NodeType &sipStrings_QtQuick[7030]
#define sipNameNr_Renderer 1089
#define sipName_Renderer &sipStrings_QtQuick[1089]
#define sipNameNr_Resource 1258
#define sipName_Resource &sipStrings_QtQuick[1258]
#define sipNameNr_Software 12987
#define sipName_Software &sipStrings_QtQuick[12987]
#define sipNameNr_SrcAlpha 7761
#define sipName_SrcAlpha &sipStrings_QtQuick[7761]
#define sipNameNr_SrcColor 7778
#define sipName_SrcColor &sipStrings_QtQuick[7778]
#define sipNameNr_Subtract 8616
#define sipName_Subtract &sipStrings_QtQuick[8616]
#define sipNameNr_TopRight 12996
#define sipName_TopRight &sipStrings_QtQuick[12996]
#define sipNameNr_WrapMode 4707
#define sipName_WrapMode &sipStrings_QtQuick[4707]
#define sipNameNr_allocate 13005
#define sipName_allocate &sipStrings_QtQuick[13005]
#define sipNameNr_clipList 13014
#define sipName_clipList &sipStrings_QtQuick[13014]
#define sipNameNr_clipRect 13023
#define sipName_clipRect &sipStrings_QtQuick[13023]
#define sipNameNr_contains 13032
#define sipName_contains &sipStrings_QtQuick[13032]
#define sipNameNr_cullMode 13041
#define sipName_cullMode &sipStrings_QtQuick[13041]
#define sipNameNr_dstAlpha 13050
#define sipName_dstAlpha &sipStrings_QtQuick[13050]
#define sipNameNr_dstColor 13059
#define sipName_dstColor &sipStrings_QtQuick[13059]
#define sipNameNr_endFrame 13068
#define sipName_endFrame &sipStrings_QtQuick[13068]
#define sipNameNr_finished 13077
#define sipName_finished &sipStrings_QtQuick[13077]
#define sipNameNr_geometry 13086
#define sipName_geometry &sipStrings_QtQuick[13086]
#define sipNameNr_hasFocus 13095
#define sipName_hasFocus &sipStrings_QtQuick[13095]
#define sipNameNr_material 13104
#define sipName_material &sipStrings_QtQuick[13104]
#define sipNameNr_position 13113
#define sipName_position &sipStrings_QtQuick[13113]
#define sipNameNr_rotation 13122
#define sipName_rotation &sipStrings_QtQuick[13122]
#define sipNameNr_setColor 13131
#define sipName_setColor &sipStrings_QtQuick[13131]
#define sipNameNr_setFlags 13140
#define sipName_setFlags &sipStrings_QtQuick[13140]
#define sipNameNr_setFocus 13149
#define sipName_setFocus &sipStrings_QtQuick[13149]
#define sipNameNr_setScale 13158
#define sipName_setScale &sipStrings_QtQuick[13158]
#define sipNameNr_setState 13167
#define sipName_setState &sipStrings_QtQuick[13167]
#define sipNameNr_setWidth 12385
#define sipName_setWidth &sipStrings_QtQuick[12385]
#define sipNameNr_srcAlpha 13176
#define sipName_srcAlpha &sipStrings_QtQuick[13176]
#define sipNameNr_srcColor 13185
#define sipName_srcColor &sipStrings_QtQuick[13185]
#define sipNameNr_viewport 13194
#define sipName_viewport &sipStrings_QtQuick[13194]
#define sipNameNr_xChanged 13203
#define sipName_xChanged &sipStrings_QtQuick[13203]
#define sipNameNr_yChanged 3557
#define sipName_yChanged &sipStrings_QtQuick[3557]
#define sipNameNr_zChanged 13212
#define sipName_zChanged &sipStrings_QtQuick[13212]
#define sipNameNr_BlendOp 604
#define sipName_BlendOp &sipStrings_QtQuick[604]
#define sipNameNr_IntType 8649
#define sipName_IntType &sipStrings_QtQuick[8649]
#define sipNameNr_Loading 13221
#define sipName_Loading &sipStrings_QtQuick[13221]
#define sipNameNr_Nearest 13229
#define sipName_Nearest &sipStrings_QtQuick[13229]
#define sipNameNr_NoStage 13237
#define sipName_NoStage &sipStrings_QtQuick[13237]
#define sipNameNr_NullRhi 13245
#define sipName_NullRhi &sipStrings_QtQuick[13245]
#define sipNameNr_Outline 13253
#define sipName_Outline &sipStrings_QtQuick[13253]
#define sipNameNr_Point2D 1226
#define sipName_Point2D &sipStrings_QtQuick[1226]
#define sipNameNr_QSGNode 13261
#define sipName_QSGNode &sipStrings_QtQuick[13261]
#define sipNameNr_TopLeft 13269
#define sipName_TopLeft &sipStrings_QtQuick[13269]
#define sipNameNr_Unknown 13277
#define sipName_Unknown &sipStrings_QtQuick[13277]
#define sipNameNr___len__ 13285
#define sipName___len__ &sipStrings_QtQuick[13285]
#define sipNameNr_childAt 13293
#define sipName_childAt &sipStrings_QtQuick[13293]
#define sipNameNr_closing 13301
#define sipName_closing &sipStrings_QtQuick[13301]
#define sipNameNr_compare 13309
#define sipName_compare &sipStrings_QtQuick[13309]
#define sipNameNr_enabled 13317
#define sipName_enabled &sipStrings_QtQuick[13317]
#define sipNameNr_forward 13325
#define sipName_forward &sipStrings_QtQuick[13325]
#define sipNameNr_opAlpha 13333
#define sipName_opAlpha &sipStrings_QtQuick[13333]
#define sipNameNr_opColor 13341
#define sipName_opColor &sipStrings_QtQuick[13341]
#define sipNameNr_opacity 13349
#define sipName_opacity &sipStrings_QtQuick[13349]
#define sipNameNr_options 13357
#define sipName_options &sipStrings_QtQuick[13357]
#define sipNameNr_prepare 13365
#define sipName_prepare &sipStrings_QtQuick[13365]
#define sipNameNr_queries 13373
#define sipName_queries &sipStrings_QtQuick[13373]
#define sipNameNr_samples 13381
#define sipName_samples &sipStrings_QtQuick[13381]
#define sipNameNr_setClip 13389
#define sipName_setClip &sipStrings_QtQuick[13389]
#define sipNameNr_setFlag 13397
#define sipName_setFlag &sipStrings_QtQuick[13397]
#define sipNameNr_setRect 13405
#define sipName_setRect &sipStrings_QtQuick[13405]
#define sipNameNr_setSize 13413
#define sipName_setSize &sipStrings_QtQuick[13413]
#define sipNameNr_texture 13421
#define sipName_texture &sipStrings_QtQuick[13421]
#define sipNameNr_Bottom 13429
#define sipName_Bottom &sipStrings_QtQuick[13429]
#define sipNameNr_Center 13436
#define sipName_Center &sipStrings_QtQuick[13436]
#define sipNameNr_Linear 13443
#define sipName_Linear &sipStrings_QtQuick[13443]
#define sipNameNr_Loaded 13450
#define sipName_Loaded &sipStrings_QtQuick[13450]
#define sipNameNr_Normal 13457
#define sipName_Normal &sipStrings_QtQuick[13457]
#define sipNameNr_OpenGL 13464
#define sipName_OpenGL &sipStrings_QtQuick[13464]
#define sipNameNr_OpenVG 13471
#define sipName_OpenVG &sipStrings_QtQuick[13471]
#define sipNameNr_Raised 13478
#define sipName_Raised &sipStrings_QtQuick[13478]
#define sipNameNr_Repeat 9282
#define sipName_Repeat &sipStrings_QtQuick[9282]
#define sipNameNr_Saving 13485
#define sipName_Saving &sipStrings_QtQuick[13485]
#define sipNameNr_Status 2301
#define sipName_Status &sipStrings_QtQuick[2301]
#define sipNameNr_Sunken 13492
#define sipName_Sunken &sipStrings_QtQuick[13492]
#define sipNameNr_Vulkan 13499
#define sipName_Vulkan &sipStrings_QtQuick[13499]
#define sipNameNr___eq__ 13506
#define sipName___eq__ &sipStrings_QtQuick[13506]
#define sipNameNr___ne__ 13513
#define sipName___ne__ &sipStrings_QtQuick[13513]
#define sipNameNr_cancel 13520
#define sipName_cancel &sipStrings_QtQuick[13520]
#define sipNameNr_create 13527
#define sipName_create &sipStrings_QtQuick[13527]
#define sipNameNr_cursor 13534
#define sipName_cursor &sipStrings_QtQuick[13534]
#define sipNameNr_engine 13541
#define sipName_engine &sipStrings_QtQuick[13541]
#define sipNameNr_errors 13548
#define sipName_errors &sipStrings_QtQuick[13548]
#define sipNameNr_format 13555
#define sipName_format &sipStrings_QtQuick[13555]
#define sipNameNr_height 13562
#define sipName_height &sipStrings_QtQuick[13562]
#define sipNameNr_isNull 13569
#define sipName_isNull &sipStrings_QtQuick[13569]
#define sipNameNr_matrix 13576
#define sipName_matrix &sipStrings_QtQuick[13576]
#define sipNameNr_mipmap 13583
#define sipName_mipmap &sipStrings_QtQuick[13583]
#define sipNameNr_offset 13590
#define sipName_offset &sipStrings_QtQuick[13590]
#define sipNameNr_parent 13597
#define sipName_parent &sipStrings_QtQuick[13597]
#define sipNameNr_polish 13604
#define sipName_polish &sipStrings_QtQuick[13604]
#define sipNameNr_render 13611
#define sipName_render &sipStrings_QtQuick[13611]
#define sipNameNr_saveAs 13618
#define sipName_saveAs &sipStrings_QtQuick[13618]
#define sipNameNr_smooth 13625
#define sipName_smooth &sipStrings_QtQuick[13625]
#define sipNameNr_source 1260
#define sipName_source &sipStrings_QtQuick[1260]
#define sipNameNr_status 13632
#define sipName_status &sipStrings_QtQuick[13632]
#define sipNameNr_stride 13639
#define sipName_stride &sipStrings_QtQuick[13639]
#define sipNameNr_update 13646
#define sipName_update &sipStrings_QtQuick[13646]
#define sipNameNr_window 13653
#define sipName_window &sipStrings_QtQuick[13653]
#define sipNameNr_Error 1739
#define sipName_Error &sipStrings_QtQuick[1739]
#define sipNameNr_Image 4023
#define sipName_Image &sipStrings_QtQuick[4023]
#define sipNameNr_Metal 13660
#define sipName_Metal &sipStrings_QtQuick[13660]
#define sipNameNr_None_ 13666
#define sipName_None_ &sipStrings_QtQuick[13666]
#define sipNameNr_Ready 13672
#define sipName_Ready &sipStrings_QtQuick[13672]
#define sipNameNr_Right 11266
#define sipName_Right &sipStrings_QtQuick[11266]
#define sipNameNr_Saved 13678
#define sipName_Saved &sipStrings_QtQuick[13678]
#define sipNameNr_Stage 2515
#define sipName_Stage &sipStrings_QtQuick[2515]
#define sipNameNr_clear 13684
#define sipName_clear &sipStrings_QtQuick[13684]
#define sipNameNr_color 13690
#define sipName_color &sipStrings_QtQuick[13690]
#define sipNameNr_count 13696
#define sipName_count &sipStrings_QtQuick[13696]
#define sipNameNr_event 13702
#define sipName_event &sipStrings_QtQuick[13702]
#define sipNameNr_flags 13708
#define sipName_flags &sipStrings_QtQuick[13708]
#define sipNameNr_image 13714
#define sipName_image &sipStrings_QtQuick[13714]
#define sipNameNr_paint 13720
#define sipName_paint &sipStrings_QtQuick[13720]
#define sipNameNr_ready 13726
#define sipName_ready &sipStrings_QtQuick[13726]
#define sipNameNr_scale 13732
#define sipName_scale &sipStrings_QtQuick[13732]
#define sipNameNr_state 13738
#define sipName_state &sipStrings_QtQuick[13738]
#define sipNameNr_width 13744
#define sipName_width &sipStrings_QtQuick[13744]
#define sipNameNr_Fill 13750
#define sipName_Fill &sipStrings_QtQuick[13750]
#define sipNameNr_Flag 403
#define sipName_Flag &sipStrings_QtQuick[403]
#define sipNameNr_GLSL 13755
#define sipName_GLSL &sipStrings_QtQuick[13755]
#define sipNameNr_HLSL 13760
#define sipName_HLSL &sipStrings_QtQuick[13760]
#define sipNameNr_Left 11949
#define sipName_Left &sipStrings_QtQuick[11949]
#define sipNameNr_Line 13765
#define sipName_Line &sipStrings_QtQuick[13765]
#define sipNameNr_Null 13571
#define sipName_Null &sipStrings_QtQuick[13571]
#define sipNameNr_Type 744
#define sipName_Type &sipStrings_QtQuick[744]
#define sipNameNr_Zero 13770
#define sipName_Zero &sipStrings_QtQuick[13770]
#define sipNameNr_clip 13775
#define sipName_clip &sipStrings_QtQuick[13775]
#define sipNameNr_item 13780
#define sipName_item &sipStrings_QtQuick[13780]
#define sipNameNr_rect 13785
#define sipName_rect &sipStrings_QtQuick[13785]
#define sipNameNr_save 13790
#define sipName_save &sipStrings_QtQuick[13790]
#define sipNameNr_setX 13795
#define sipName_setX &sipStrings_QtQuick[13795]
#define sipNameNr_setY 13800
#define sipName_setY &sipStrings_QtQuick[13800]
#define sipNameNr_setZ 13805
#define sipName_setZ &sipStrings_QtQuick[13805]
#define sipNameNr_size 13810
#define sipName_size &sipStrings_QtQuick[13810]
#define sipNameNr_sync 13815
#define sipName_sync &sipStrings_QtQuick[13815]
#define sipNameNr_type 13820
#define sipName_type &sipStrings_QtQuick[13820]
#define sipNameNr_Add 13825
#define sipName_Add &sipStrings_QtQuick[13825]
#define sipNameNr_Max 13829
#define sipName_Max &sipStrings_QtQuick[13829]
#define sipNameNr_Min 13833
#define sipName_Min &sipStrings_QtQuick[13833]
#define sipNameNr_One 13837
#define sipName_One &sipStrings_QtQuick[13837]
#define sipNameNr_Top 13841
#define sipName_Top &sipStrings_QtQuick[13841]
#define sipNameNr_get 1524
#define sipName_get &sipStrings_QtQuick[1524]
#define sipNameNr_set 7431
#define sipName_set &sipStrings_QtQuick[7431]
#define sipNameNr_url 13845
#define sipName_url &sipStrings_QtQuick[13845]
#define sipNameNr_on 1129
#define sipName_on &sipStrings_QtQuick[1129]
#define sipNameNr_tx 13849
#define sipName_tx &sipStrings_QtQuick[13849]
#define sipNameNr_ty 5472
#define sipName_ty &sipStrings_QtQuick[5472]
#define sipNameNr_A 13852
#define sipName_A &sipStrings_QtQuick[13852]
#define sipNameNr_B 13854
#define sipName_B &sipStrings_QtQuick[13854]
#define sipNameNr_G 13476
#define sipName_G &sipStrings_QtQuick[13476]
#define sipNameNr_R 13856
#define sipName_R &sipStrings_QtQuick[13856]
#define sipNameNr_a 1494
#define sipName_a &sipStrings_QtQuick[1494]
#define sipNameNr_b 5995
#define sipName_b &sipStrings_QtQuick[5995]
#define sipNameNr_g 406
#define sipName_g &sipStrings_QtQuick[406]
#define sipNameNr_r 298
#define sipName_r &sipStrings_QtQuick[298]
#define sipNameNr_x 6422
#define sipName_x &sipStrings_QtQuick[6422]
#define sipNameNr_y 2414
#define sipName_y &sipStrings_QtQuick[2414]
#define sipNameNr_z 13858
#define sipName_z &sipStrings_QtQuick[13858]

#define sipMalloc                   sipAPI_QtQuick->api_malloc
#define sipFree                     sipAPI_QtQuick->api_free
#define sipBuildResult              sipAPI_QtQuick->api_build_result
#define sipCallMethod               sipAPI_QtQuick->api_call_method
#define sipCallProcedureMethod      sipAPI_QtQuick->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtQuick->api_call_error_handler
#define sipParseResultEx            sipAPI_QtQuick->api_parse_result_ex
#define sipParseResult              sipAPI_QtQuick->api_parse_result
#define sipParseArgs                sipAPI_QtQuick->api_parse_args
#define sipParseKwdArgs             sipAPI_QtQuick->api_parse_kwd_args
#define sipParsePair                sipAPI_QtQuick->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtQuick->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtQuick->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtQuick->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtQuick->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtQuick->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtQuick->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtQuick->api_add_exception
#define sipNoFunction               sipAPI_QtQuick->api_no_function
#define sipNoMethod                 sipAPI_QtQuick->api_no_method
#define sipAbstractMethod           sipAPI_QtQuick->api_abstract_method
#define sipBadClass                 sipAPI_QtQuick->api_bad_class
#define sipBadCatcherResult         sipAPI_QtQuick->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtQuick->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtQuick->api_bad_operator_arg
#define sipTrace                    sipAPI_QtQuick->api_trace
#define sipTransferBack             sipAPI_QtQuick->api_transfer_back
#define sipTransferTo               sipAPI_QtQuick->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtQuick->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtQuick->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtQuick->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtQuick->api_voidptr_type
#define sipGetPyObject              sipAPI_QtQuick->api_get_pyobject
#define sipGetAddress               sipAPI_QtQuick->api_get_address
#define sipGetMixinAddress          sipAPI_QtQuick->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtQuick->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtQuick->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtQuick->api_call_hook
#define sipEndThread                sipAPI_QtQuick->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtQuick->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtQuick->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtQuick->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtQuick->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtQuick->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtQuick->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtQuick->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtQuick->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtQuick->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtQuick->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtQuick->api_convert_to_bool
#define sipReleaseType              sipAPI_QtQuick->api_release_type
#define sipConvertFromType          sipAPI_QtQuick->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtQuick->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtQuick->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtQuick->api_convert_from_enum
#define sipGetState                 sipAPI_QtQuick->api_get_state
#define sipExportSymbol             sipAPI_QtQuick->api_export_symbol
#define sipImportSymbol             sipAPI_QtQuick->api_import_symbol
#define sipFindType                 sipAPI_QtQuick->api_find_type
#define sipBytes_AsChar             sipAPI_QtQuick->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtQuick->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtQuick->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtQuick->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtQuick->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtQuick->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtQuick->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtQuick->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtQuick->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtQuick->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtQuick->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtQuick->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtQuick->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtQuick->api_get_reference
#define sipKeepReference            sipAPI_QtQuick->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtQuick->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtQuick->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtQuick->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtQuick->api_type_scope
#define sipResolveTypedef           sipAPI_QtQuick->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtQuick->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtQuick->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtQuick->api_init_mixin
#define sipExportModule             sipAPI_QtQuick->api_export_module
#define sipInitModule               sipAPI_QtQuick->api_init_module
#define sipGetInterpreter           sipAPI_QtQuick->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtQuick->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtQuick->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtQuick->api_py_type_dict
#define sipPyTypeName               sipAPI_QtQuick->api_py_type_name
#define sipGetCFunction             sipAPI_QtQuick->api_get_c_function
#define sipGetMethod                sipAPI_QtQuick->api_get_method
#define sipFromMethod               sipAPI_QtQuick->api_from_method
#define sipGetDate                  sipAPI_QtQuick->api_get_date
#define sipFromDate                 sipAPI_QtQuick->api_from_date
#define sipGetDateTime              sipAPI_QtQuick->api_get_datetime
#define sipFromDateTime             sipAPI_QtQuick->api_from_datetime
#define sipGetTime                  sipAPI_QtQuick->api_get_time
#define sipFromTime                 sipAPI_QtQuick->api_from_time
#define sipIsUserType               sipAPI_QtQuick->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtQuick->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtQuick->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtQuick->api_unicode_write
#define sipUnicodeData              sipAPI_QtQuick->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtQuick->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtQuick->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtQuick->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtQuick->api_is_derived_class
#define sipGetUserObject            sipAPI_QtQuick->api_get_user_object
#define sipSetUserObject            sipAPI_QtQuick->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtQuick->api_register_event_handler
#define sipConvertToArray           sipAPI_QtQuick->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtQuick->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtQuick->api_enable_gc
#define sipPrintObject              sipAPI_QtQuick->api_print_object
#define sipLong_AsChar              sipAPI_QtQuick->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtQuick->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtQuick->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtQuick->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtQuick->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtQuick->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtQuick->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtQuick->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtQuick->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtQuick->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtQuick->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtQuick->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtQuick->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtQuick->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtQuick->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtQuick->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtQuick->api_next_exception_handler
#define sipIsEnumFlag               sipAPI_QtQuick->api_is_enum_flag
#define sipConvertToTypeUS          sipAPI_QtQuick->api_convert_to_type_us
#define sipForceConvertToTypeUS     sipAPI_QtQuick->api_force_convert_to_type_us
#define sipReleaseTypeUS            sipAPI_QtQuick->api_release_type_us
#define sipIsPyMethod               sipAPI_QtQuick->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtQuick[];

#define sipType_QOpenGLFramebufferObject sipExportedTypes_QtQuick[19]

#define sipType_QQuickItem sipExportedTypes_QtQuick[28]

#define sipType_QQuickItem_TransformOrigin sipExportedTypes_QtQuick[32]

#define sipType_QQuickItem_ItemChange sipExportedTypes_QtQuick[30]

#define sipType_QQuickItem_Flag sipExportedTypes_QtQuick[29]

extern sipClassTypeDef sipTypeDef_QtQuick_QQuickItem;
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQuick/qquickitem.sip"
#include <qquickitem.h>
#line 2075 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipAPIQtQuick.h"


class sipQQuickItem : public ::QQuickItem
{
public:
    sipQQuickItem(::QQuickItem*);
    virtual ~sipQQuickItem();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void updatePolish() SIP_OVERRIDE;
    void releaseResources() SIP_OVERRIDE;
    ::QSGNode* updatePaintNode(::QSGNode*, ::QQuickItem::UpdatePaintNodeData*) SIP_OVERRIDE;
    void geometryChange(const ::QRectF&, const ::QRectF&) SIP_OVERRIDE;
    bool childMouseEventFilter(::QQuickItem*, ::QEvent*) SIP_OVERRIDE;
    void dropEvent(::QDropEvent*) SIP_OVERRIDE;
    void dragLeaveEvent(::QDragLeaveEvent*) SIP_OVERRIDE;
    void dragMoveEvent(::QDragMoveEvent*) SIP_OVERRIDE;
    void dragEnterEvent(::QDragEnterEvent*) SIP_OVERRIDE;
    void hoverLeaveEvent(::QHoverEvent*) SIP_OVERRIDE;
    void hoverMoveEvent(::QHoverEvent*) SIP_OVERRIDE;
    void hoverEnterEvent(::QHoverEvent*) SIP_OVERRIDE;
    void touchEvent(::QTouchEvent*) SIP_OVERRIDE;
    void wheelEvent(::QWheelEvent*) SIP_OVERRIDE;
    void touchUngrabEvent() SIP_OVERRIDE;
    void mouseUngrabEvent() SIP_OVERRIDE;
    void mouseDoubleClickEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseMoveEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mousePressEvent(::QMouseEvent*) SIP_OVERRIDE;
    void focusOutEvent(::QFocusEvent*) SIP_OVERRIDE;
    void focusInEvent(::QFocusEvent*) SIP_OVERRIDE;
    void inputMethodEvent(::QInputMethodEvent*) SIP_OVERRIDE;
    void keyReleaseEvent(::QKeyEvent*) SIP_OVERRIDE;
    void keyPressEvent(::QKeyEvent*) SIP_OVERRIDE;
    void itemChange(::QQuickItem::ItemChange, const ::QQuickItem::ItemChangeData&) SIP_OVERRIDE;
    ::QSGTextureProvider* textureProvider() const SIP_OVERRIDE;
    bool isTextureProvider() const SIP_OVERRIDE;
    ::QVariant inputMethodQuery(::Qt::InputMethodQuery) const SIP_OVERRIDE;
    bool contains(const ::QPointF&) const SIP_OVERRIDE;
    void classBegin() SIP_OVERRIDE;
    void componentComplete() SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQQuickItem(const sipQQuickItem &);
    sipQQuickItem &operator = (const sipQQuickItem &);

    char sipPyMethods[39];
};

#define sipType_QQuickFramebufferObject sipExportedTypes_QtQuick[22]

extern sipClassTypeDef sipTypeDef_QtQuick_QQuickFramebufferObject;
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQuick/qquickframebufferobject.sip"
#include <qquickframebufferobject.h>
#line 2148 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipAPIQtQuick.h"


class sipQQuickFramebufferObject : public ::QQuickFramebufferObject
{
public:
    sipQQuickFramebufferObject(::QQuickItem*);
    virtual ~sipQQuickFramebufferObject();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    ::QQuickFramebufferObject::Renderer* createRenderer() const SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    void componentComplete() SIP_OVERRIDE;
    void classBegin() SIP_OVERRIDE;
    bool contains(const ::QPointF&) const SIP_OVERRIDE;
    ::QVariant inputMethodQuery(::Qt::InputMethodQuery) const SIP_OVERRIDE;
    bool isTextureProvider() const SIP_OVERRIDE;
    ::QSGTextureProvider* textureProvider() const SIP_OVERRIDE;
    void itemChange(::QQuickItem::ItemChange, const ::QQuickItem::ItemChangeData&) SIP_OVERRIDE;
    void keyPressEvent(::QKeyEvent*) SIP_OVERRIDE;
    void keyReleaseEvent(::QKeyEvent*) SIP_OVERRIDE;
    void inputMethodEvent(::QInputMethodEvent*) SIP_OVERRIDE;
    void focusInEvent(::QFocusEvent*) SIP_OVERRIDE;
    void focusOutEvent(::QFocusEvent*) SIP_OVERRIDE;
    void mousePressEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseMoveEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseUngrabEvent() SIP_OVERRIDE;
    void touchUngrabEvent() SIP_OVERRIDE;
    void wheelEvent(::QWheelEvent*) SIP_OVERRIDE;
    void touchEvent(::QTouchEvent*) SIP_OVERRIDE;
    void hoverEnterEvent(::QHoverEvent*) SIP_OVERRIDE;
    void hoverMoveEvent(::QHoverEvent*) SIP_OVERRIDE;
    void hoverLeaveEvent(::QHoverEvent*) SIP_OVERRIDE;
    void dragEnterEvent(::QDragEnterEvent*) SIP_OVERRIDE;
    void dragMoveEvent(::QDragMoveEvent*) SIP_OVERRIDE;
    void dragLeaveEvent(::QDragLeaveEvent*) SIP_OVERRIDE;
    void dropEvent(::QDropEvent*) SIP_OVERRIDE;
    bool childMouseEventFilter(::QQuickItem*, ::QEvent*) SIP_OVERRIDE;
    void geometryChange(const ::QRectF&, const ::QRectF&) SIP_OVERRIDE;
    ::QSGNode* updatePaintNode(::QSGNode*, ::QQuickItem::UpdatePaintNodeData*) SIP_OVERRIDE;
    void releaseResources() SIP_OVERRIDE;
    void updatePolish() SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQQuickFramebufferObject(const sipQQuickFramebufferObject &);
    sipQQuickFramebufferObject &operator = (const sipQQuickFramebufferObject &);

    char sipPyMethods[40];
};

#define sipType_QQuickFramebufferObject_Renderer sipExportedTypes_QtQuick[23]

extern sipClassTypeDef sipTypeDef_QtQuick_QQuickFramebufferObject_Renderer;

#define sipType_QQuickGraphicsConfiguration sipExportedTypes_QtQuick[24]

extern sipClassTypeDef sipTypeDef_QtQuick_QQuickGraphicsConfiguration;

#define sipType_QQuickGraphicsDevice sipExportedTypes_QtQuick[25]

extern sipClassTypeDef sipTypeDef_QtQuick_QQuickGraphicsDevice;

#define sipType_QQuickTextureFactory sipExportedTypes_QtQuick[43]

extern sipClassTypeDef sipTypeDef_QtQuick_QQuickTextureFactory;

#define sipType_QQuickImageProvider sipExportedTypes_QtQuick[26]

extern sipClassTypeDef sipTypeDef_QtQuick_QQuickImageProvider;

#define sipType_QQuickImageResponse sipExportedTypes_QtQuick[27]

extern sipClassTypeDef sipTypeDef_QtQuick_QQuickImageResponse;

#define sipType_QQuickAsyncImageProvider sipExportedTypes_QtQuick[20]

extern sipClassTypeDef sipTypeDef_QtQuick_QQuickAsyncImageProvider;

#define sipType_QQuickItem_ItemChangeData sipExportedTypes_QtQuick[31]

extern sipClassTypeDef sipTypeDef_QtQuick_QQuickItem_ItemChangeData;

#define sipType_QQuickItem_UpdatePaintNodeData sipExportedTypes_QtQuick[33]

extern sipClassTypeDef sipTypeDef_QtQuick_QQuickItem_UpdatePaintNodeData;

#define sipType_QQuickItemGrabResult sipExportedTypes_QtQuick[34]

extern sipClassTypeDef sipTypeDef_QtQuick_QQuickItemGrabResult;

#define sipType_QQuickPaintedItem sipExportedTypes_QtQuick[35]

#define sipType_QQuickPaintedItem_PerformanceHint sipExportedTypes_QtQuick[36]

#define sipType_QQuickPaintedItem_RenderTarget sipExportedTypes_QtQuick[37]

extern sipClassTypeDef sipTypeDef_QtQuick_QQuickPaintedItem;
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQuick/qquickpainteditem.sip"
#include <qquickpainteditem.h>
#line 2266 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipAPIQtQuick.h"


class sipQQuickPaintedItem : public ::QQuickPaintedItem
{
public:
    sipQQuickPaintedItem(::QQuickItem*);
    virtual ~sipQQuickPaintedItem();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void paint(::QPainter*) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    void componentComplete() SIP_OVERRIDE;
    void classBegin() SIP_OVERRIDE;
    bool contains(const ::QPointF&) const SIP_OVERRIDE;
    ::QVariant inputMethodQuery(::Qt::InputMethodQuery) const SIP_OVERRIDE;
    bool isTextureProvider() const SIP_OVERRIDE;
    ::QSGTextureProvider* textureProvider() const SIP_OVERRIDE;
    void itemChange(::QQuickItem::ItemChange, const ::QQuickItem::ItemChangeData&) SIP_OVERRIDE;
    void keyPressEvent(::QKeyEvent*) SIP_OVERRIDE;
    void keyReleaseEvent(::QKeyEvent*) SIP_OVERRIDE;
    void inputMethodEvent(::QInputMethodEvent*) SIP_OVERRIDE;
    void focusInEvent(::QFocusEvent*) SIP_OVERRIDE;
    void focusOutEvent(::QFocusEvent*) SIP_OVERRIDE;
    void mousePressEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseMoveEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseUngrabEvent() SIP_OVERRIDE;
    void touchUngrabEvent() SIP_OVERRIDE;
    void wheelEvent(::QWheelEvent*) SIP_OVERRIDE;
    void touchEvent(::QTouchEvent*) SIP_OVERRIDE;
    void hoverEnterEvent(::QHoverEvent*) SIP_OVERRIDE;
    void hoverMoveEvent(::QHoverEvent*) SIP_OVERRIDE;
    void hoverLeaveEvent(::QHoverEvent*) SIP_OVERRIDE;
    void dragEnterEvent(::QDragEnterEvent*) SIP_OVERRIDE;
    void dragMoveEvent(::QDragMoveEvent*) SIP_OVERRIDE;
    void dragLeaveEvent(::QDragLeaveEvent*) SIP_OVERRIDE;
    void dropEvent(::QDropEvent*) SIP_OVERRIDE;
    bool childMouseEventFilter(::QQuickItem*, ::QEvent*) SIP_OVERRIDE;
    void geometryChange(const ::QRectF&, const ::QRectF&) SIP_OVERRIDE;
    ::QSGNode* updatePaintNode(::QSGNode*, ::QQuickItem::UpdatePaintNodeData*) SIP_OVERRIDE;
    void releaseResources() SIP_OVERRIDE;
    void updatePolish() SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQQuickPaintedItem(const sipQQuickPaintedItem &);
    sipQQuickPaintedItem &operator = (const sipQQuickPaintedItem &);

    char sipPyMethods[40];
};

#define sipType_QQuickRenderControl sipExportedTypes_QtQuick[38]

extern sipClassTypeDef sipTypeDef_QtQuick_QQuickRenderControl;

#define sipType_QQuickRenderTarget sipExportedTypes_QtQuick[39]

#define sipType_QQuickRenderTarget_Flag sipExportedTypes_QtQuick[40]

extern sipClassTypeDef sipTypeDef_QtQuick_QQuickRenderTarget;

#define sipType_QQuickTextDocument sipExportedTypes_QtQuick[41]

#define sipType_QQuickTextDocument_Status sipExportedTypes_QtQuick[42]

extern sipClassTypeDef sipTypeDef_QtQuick_QQuickTextDocument;

#define sipType_QQuickWindow sipExportedTypes_QtQuick[47]

#define sipType_QQuickWindow_TextRenderType sipExportedTypes_QtQuick[51]

#define sipType_QQuickWindow_RenderStage sipExportedTypes_QtQuick[49]

#define sipType_QQuickWindow_SceneGraphError sipExportedTypes_QtQuick[50]

#define sipType_QQuickWindow_CreateTextureOption sipExportedTypes_QtQuick[48]

extern sipClassTypeDef sipTypeDef_QtQuick_QQuickWindow;
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQuick/qquickwindow.sip"
#include <qquickwindow.h>
#line 2364 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipAPIQtQuick.h"


class sipQQuickWindow : public ::QQuickWindow
{
public:
    sipQQuickWindow(::QWindow*);
    virtual ~sipQQuickWindow();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    ::QSize size() const SIP_OVERRIDE;
    ::QSurface::SurfaceType surfaceType() const SIP_OVERRIDE;
    ::QSurfaceFormat format() const SIP_OVERRIDE;
    ::QObject* focusObject() const SIP_OVERRIDE;
    void exposeEvent(::QExposeEvent*) SIP_OVERRIDE;
    void resizeEvent(::QResizeEvent*) SIP_OVERRIDE;
    void moveEvent(::QMoveEvent*) SIP_OVERRIDE;
    void focusInEvent(::QFocusEvent*) SIP_OVERRIDE;
    void focusOutEvent(::QFocusEvent*) SIP_OVERRIDE;
    void showEvent(::QShowEvent*) SIP_OVERRIDE;
    void hideEvent(::QHideEvent*) SIP_OVERRIDE;
    void keyPressEvent(::QKeyEvent*) SIP_OVERRIDE;
    void keyReleaseEvent(::QKeyEvent*) SIP_OVERRIDE;
    void mousePressEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseMoveEvent(::QMouseEvent*) SIP_OVERRIDE;
    void wheelEvent(::QWheelEvent*) SIP_OVERRIDE;
    void touchEvent(::QTouchEvent*) SIP_OVERRIDE;
    void tabletEvent(::QTabletEvent*) SIP_OVERRIDE;
    void paintEvent(::QPaintEvent*) SIP_OVERRIDE;
    void closeEvent(::QCloseEvent*) SIP_OVERRIDE;
    bool nativeEvent(const ::QByteArray&, void*, ::qintptr*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQQuickWindow(const sipQQuickWindow &);
    sipQQuickWindow &operator = (const sipQQuickWindow &);

    char sipPyMethods[30];
};

#define sipType_QQuickView sipExportedTypes_QtQuick[44]

#define sipType_QQuickView_Status sipExportedTypes_QtQuick[46]

#define sipType_QQuickView_ResizeMode sipExportedTypes_QtQuick[45]

extern sipClassTypeDef sipTypeDef_QtQuick_QQuickView;
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQuick/qquickview.sip"
#include <qquickview.h>
#line 2432 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipAPIQtQuick.h"


class sipQQuickView : public ::QQuickView
{
public:
    sipQQuickView(::QWindow*);
    sipQQuickView(::QQmlEngine*, ::QWindow*);
    sipQQuickView(const ::QUrl&, ::QWindow*);
    sipQQuickView(::QAnyStringView, ::QAnyStringView, ::QWindow*);
    virtual ~sipQQuickView();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool nativeEvent(const ::QByteArray&, void*, ::qintptr*) SIP_OVERRIDE;
    void closeEvent(::QCloseEvent*) SIP_OVERRIDE;
    void paintEvent(::QPaintEvent*) SIP_OVERRIDE;
    void tabletEvent(::QTabletEvent*) SIP_OVERRIDE;
    void touchEvent(::QTouchEvent*) SIP_OVERRIDE;
    void wheelEvent(::QWheelEvent*) SIP_OVERRIDE;
    void mouseMoveEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mousePressEvent(::QMouseEvent*) SIP_OVERRIDE;
    void keyReleaseEvent(::QKeyEvent*) SIP_OVERRIDE;
    void keyPressEvent(::QKeyEvent*) SIP_OVERRIDE;
    void hideEvent(::QHideEvent*) SIP_OVERRIDE;
    void showEvent(::QShowEvent*) SIP_OVERRIDE;
    void focusOutEvent(::QFocusEvent*) SIP_OVERRIDE;
    void focusInEvent(::QFocusEvent*) SIP_OVERRIDE;
    void moveEvent(::QMoveEvent*) SIP_OVERRIDE;
    void resizeEvent(::QResizeEvent*) SIP_OVERRIDE;
    void exposeEvent(::QExposeEvent*) SIP_OVERRIDE;
    ::QObject* focusObject() const SIP_OVERRIDE;
    ::QSurfaceFormat format() const SIP_OVERRIDE;
    ::QSurface::SurfaceType surfaceType() const SIP_OVERRIDE;
    ::QSize size() const SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQQuickView(const sipQQuickView &);
    sipQQuickView &operator = (const sipQQuickView &);

    char sipPyMethods[30];
};

#define sipType_QQuickCloseEvent sipExportedTypes_QtQuick[21]

extern sipClassTypeDef sipTypeDef_QtQuick_QQuickCloseEvent;

#define sipType_QSGMaterial sipExportedTypes_QtQuick[69]

#define sipType_QSGMaterial_Flag sipExportedTypes_QtQuick[70]

extern sipClassTypeDef sipTypeDef_QtQuick_QSGMaterial;

#define sipType_QSGFlatColorMaterial sipExportedTypes_QtQuick[55]

extern sipClassTypeDef sipTypeDef_QtQuick_QSGFlatColorMaterial;

#define sipType_QSGGeometry sipExportedTypes_QtQuick[56]

#define sipType_QSGGeometry_Type sipExportedTypes_QtQuick[65]

#define sipType_QSGGeometry_DrawingMode sipExportedTypes_QtQuick[62]

#define sipType_QSGGeometry_AttributeType sipExportedTypes_QtQuick[59]

#define sipType_QSGGeometry_DataPattern sipExportedTypes_QtQuick[61]

extern sipClassTypeDef sipTypeDef_QtQuick_QSGGeometry;

#define sipType_QSGGeometry_Attribute sipExportedTypes_QtQuick[57]

extern sipClassTypeDef sipTypeDef_QtQuick_QSGGeometry_Attribute;

#define sipType_QSGGeometry_AttributeSet sipExportedTypes_QtQuick[58]

extern sipClassTypeDef sipTypeDef_QtQuick_QSGGeometry_AttributeSet;

#define sipType_QSGGeometry_Point2D sipExportedTypes_QtQuick[63]

extern sipClassTypeDef sipTypeDef_QtQuick_QSGGeometry_Point2D;

#define sipType_QSGGeometry_TexturedPoint2D sipExportedTypes_QtQuick[64]

extern sipClassTypeDef sipTypeDef_QtQuick_QSGGeometry_TexturedPoint2D;

#define sipType_QSGGeometry_ColoredPoint2D sipExportedTypes_QtQuick[60]

extern sipClassTypeDef sipTypeDef_QtQuick_QSGGeometry_ColoredPoint2D;

#define sipType_QSGNode sipExportedTypes_QtQuick[83]

#define sipType_QSGNode_DirtyStateBit sipExportedTypes_QtQuick[84]

#define sipType_QSGNode_Flag sipExportedTypes_QtQuick[85]

#define sipType_QSGNode_NodeType sipExportedTypes_QtQuick[86]

extern sipClassTypeDef sipTypeDef_QtQuick_QSGNode;

#define sipType_QSGBasicGeometryNode sipExportedTypes_QtQuick[52]

extern sipClassTypeDef sipTypeDef_QtQuick_QSGBasicGeometryNode;

#define sipType_QSGGeometryNode sipExportedTypes_QtQuick[66]

extern sipClassTypeDef sipTypeDef_QtQuick_QSGGeometryNode;

#define sipType_QSGImageNode sipExportedTypes_QtQuick[67]

#define sipType_QSGImageNode_TextureCoordinatesTransformFlag sipExportedTypes_QtQuick[68]

extern sipClassTypeDef sipTypeDef_QtQuick_QSGImageNode;

#define sipType_QSGMaterialShader sipExportedTypes_QtQuick[71]

#define sipType_QSGMaterialShader_Stage sipExportedTypes_QtQuick[81]

#define sipType_QSGMaterialShader_Flag sipExportedTypes_QtQuick[72]

extern sipClassTypeDef sipTypeDef_QtQuick_QSGMaterialShader;

#define sipType_QSGMaterialShader_RenderState sipExportedTypes_QtQuick[79]

#define sipType_QSGMaterialShader_RenderState_DirtyState sipExportedTypes_QtQuick[80]

extern sipClassTypeDef sipTypeDef_QtQuick_QSGMaterialShader_RenderState;

#define sipType_QSGMaterialShader_GraphicsPipelineState sipExportedTypes_QtQuick[73]

#define sipType_QSGMaterialShader_GraphicsPipelineState_PolygonMode sipExportedTypes_QtQuick[78]

#define sipType_QSGMaterialShader_GraphicsPipelineState_CullMode sipExportedTypes_QtQuick[77]

#define sipType_QSGMaterialShader_GraphicsPipelineState_ColorMaskComponent sipExportedTypes_QtQuick[76]

#define sipType_QSGMaterialShader_GraphicsPipelineState_BlendOp sipExportedTypes_QtQuick[75]

#define sipType_QSGMaterialShader_GraphicsPipelineState_BlendFactor sipExportedTypes_QtQuick[74]

extern sipClassTypeDef sipTypeDef_QtQuick_QSGMaterialShader_GraphicsPipelineState;

#define sipType_QSGMaterialType sipExportedTypes_QtQuick[82]

extern sipClassTypeDef sipTypeDef_QtQuick_QSGMaterialType;

#define sipType_QSGClipNode sipExportedTypes_QtQuick[53]

extern sipClassTypeDef sipTypeDef_QtQuick_QSGClipNode;

#define sipType_QSGTransformNode sipExportedTypes_QtQuick[113]

extern sipClassTypeDef sipTypeDef_QtQuick_QSGTransformNode;

#define sipType_QSGOpacityNode sipExportedTypes_QtQuick[87]

extern sipClassTypeDef sipTypeDef_QtQuick_QSGOpacityNode;

#define sipType_QSGRectangleNode sipExportedTypes_QtQuick[89]

extern sipClassTypeDef sipTypeDef_QtQuick_QSGRectangleNode;

#define sipType_QSGRendererInterface sipExportedTypes_QtQuick[94]

#define sipType_QSGRendererInterface_RenderMode sipExportedTypes_QtQuick[96]

#define sipType_QSGRendererInterface_ShaderSourceType sipExportedTypes_QtQuick[99]

#define sipType_QSGRendererInterface_ShaderCompilationType sipExportedTypes_QtQuick[98]

#define sipType_QSGRendererInterface_ShaderType sipExportedTypes_QtQuick[100]

#define sipType_QSGRendererInterface_Resource sipExportedTypes_QtQuick[97]

#define sipType_QSGRendererInterface_GraphicsApi sipExportedTypes_QtQuick[95]

extern sipClassTypeDef sipTypeDef_QtQuick_QSGRendererInterface;

#define sipType_QSGRenderNode sipExportedTypes_QtQuick[90]

#define sipType_QSGRenderNode_RenderingFlag sipExportedTypes_QtQuick[92]

#define sipType_QSGRenderNode_StateFlag sipExportedTypes_QtQuick[93]

extern sipClassTypeDef sipTypeDef_QtQuick_QSGRenderNode;

#define sipType_QSGRenderNode_RenderState sipExportedTypes_QtQuick[91]

extern sipClassTypeDef sipTypeDef_QtQuick_QSGRenderNode_RenderState;

#define sipType_QSGSimpleRectNode sipExportedTypes_QtQuick[101]

extern sipClassTypeDef sipTypeDef_QtQuick_QSGSimpleRectNode;

#define sipType_QSGSimpleTextureNode sipExportedTypes_QtQuick[102]

#define sipType_QSGSimpleTextureNode_TextureCoordinatesTransformFlag sipExportedTypes_QtQuick[103]

extern sipClassTypeDef sipTypeDef_QtQuick_QSGSimpleTextureNode;

#define sipType_QSGTextNode sipExportedTypes_QtQuick[104]

#define sipType_QSGTextNode_TextStyle sipExportedTypes_QtQuick[106]

#define sipType_QSGTextNode_RenderType sipExportedTypes_QtQuick[105]

extern sipClassTypeDef sipTypeDef_QtQuick_QSGTextNode;

#define sipType_QSGTexture sipExportedTypes_QtQuick[107]

#define sipType_QSGTexture_AnisotropyLevel sipExportedTypes_QtQuick[108]

#define sipType_QSGTexture_Filtering sipExportedTypes_QtQuick[109]

#define sipType_QSGTexture_WrapMode sipExportedTypes_QtQuick[110]

extern sipClassTypeDef sipTypeDef_QtQuick_QSGTexture;

#define sipType_QSGDynamicTexture sipExportedTypes_QtQuick[54]

extern sipClassTypeDef sipTypeDef_QtQuick_QSGDynamicTexture;


extern sipClassTypeDef sipTypeDef_QtQuick_QNativeInterface;

#define sipType_QNativeInterface_QSGOpenGLTexture sipExportedTypes_QtQuick[18]

extern sipClassTypeDef sipTypeDef_QtQuick_QNativeInterface_QSGOpenGLTexture;

#define sipType_QSGOpaqueTextureMaterial sipExportedTypes_QtQuick[88]

extern sipClassTypeDef sipTypeDef_QtQuick_QSGOpaqueTextureMaterial;

#define sipType_QSGTextureMaterial sipExportedTypes_QtQuick[111]

extern sipClassTypeDef sipTypeDef_QtQuick_QSGTextureMaterial;

#define sipType_QSGTextureProvider sipExportedTypes_QtQuick[112]

extern sipClassTypeDef sipTypeDef_QtQuick_QSGTextureProvider;

#define sipType_QSGVertexColorMaterial sipExportedTypes_QtQuick[114]

extern sipClassTypeDef sipTypeDef_QtQuick_QSGVertexColorMaterial;

#define sipType_QList_0101QQuickItem sipExportedTypes_QtQuick[16]

extern sipMappedTypeDef sipTypeDef_QtQuick_QList_0101QQuickItem;

#define sipType_QFlags_0100QSGSimpleTextureNode_TextureCoordinatesTransformFlag sipExportedTypes_QtQuick[15]

extern sipMappedTypeDef sipTypeDef_QtQuick_QFlags_0100QSGSimpleTextureNode_TextureCoordinatesTransformFlag;

#define sipType_QFlags_0100QSGRendererInterface_ShaderSourceType sipExportedTypes_QtQuick[14]

extern sipMappedTypeDef sipTypeDef_QtQuick_QFlags_0100QSGRendererInterface_ShaderSourceType;

#define sipType_QFlags_0100QSGRendererInterface_ShaderCompilationType sipExportedTypes_QtQuick[13]

extern sipMappedTypeDef sipTypeDef_QtQuick_QFlags_0100QSGRendererInterface_ShaderCompilationType;

#define sipType_QFlags_0100QSGRenderNode_StateFlag sipExportedTypes_QtQuick[12]

extern sipMappedTypeDef sipTypeDef_QtQuick_QFlags_0100QSGRenderNode_StateFlag;

#define sipType_QFlags_0100QSGRenderNode_RenderingFlag sipExportedTypes_QtQuick[11]

extern sipMappedTypeDef sipTypeDef_QtQuick_QFlags_0100QSGRenderNode_RenderingFlag;

#define sipType_QFlags_0100QSGNode_Flag sipExportedTypes_QtQuick[10]

extern sipMappedTypeDef sipTypeDef_QtQuick_QFlags_0100QSGNode_Flag;

#define sipType_QFlags_0100QSGNode_DirtyStateBit sipExportedTypes_QtQuick[9]

extern sipMappedTypeDef sipTypeDef_QtQuick_QFlags_0100QSGNode_DirtyStateBit;

#define sipType_QFlags_0100QSGMaterialShader_RenderState_DirtyState sipExportedTypes_QtQuick[8]

extern sipMappedTypeDef sipTypeDef_QtQuick_QFlags_0100QSGMaterialShader_RenderState_DirtyState;

#define sipType_QFlags_0100QSGMaterialShader_GraphicsPipelineState_ColorMaskComponent sipExportedTypes_QtQuick[7]

extern sipMappedTypeDef sipTypeDef_QtQuick_QFlags_0100QSGMaterialShader_GraphicsPipelineState_ColorMaskComponent;

#define sipType_QFlags_0100QSGMaterialShader_Flag sipExportedTypes_QtQuick[6]

extern sipMappedTypeDef sipTypeDef_QtQuick_QFlags_0100QSGMaterialShader_Flag;

#define sipType_QFlags_0100QSGMaterial_Flag sipExportedTypes_QtQuick[5]

extern sipMappedTypeDef sipTypeDef_QtQuick_QFlags_0100QSGMaterial_Flag;

#define sipType_QFlags_0100QSGImageNode_TextureCoordinatesTransformFlag sipExportedTypes_QtQuick[4]

extern sipMappedTypeDef sipTypeDef_QtQuick_QFlags_0100QSGImageNode_TextureCoordinatesTransformFlag;

#define sipType_QFlags_0100QQuickWindow_CreateTextureOption sipExportedTypes_QtQuick[3]

extern sipMappedTypeDef sipTypeDef_QtQuick_QFlags_0100QQuickWindow_CreateTextureOption;

#define sipType_QFlags_0100QQuickRenderTarget_Flag sipExportedTypes_QtQuick[2]

extern sipMappedTypeDef sipTypeDef_QtQuick_QFlags_0100QQuickRenderTarget_Flag;

#define sipType_QFlags_0100QQuickPaintedItem_PerformanceHint sipExportedTypes_QtQuick[1]

extern sipMappedTypeDef sipTypeDef_QtQuick_QFlags_0100QQuickPaintedItem_PerformanceHint;

#define sipType_QFlags_0100QQuickItem_Flag sipExportedTypes_QtQuick[0]

extern sipMappedTypeDef sipTypeDef_QtQuick_QFlags_0100QQuickItem_Flag;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtQuick;
extern sipExportedModuleDef sipModuleAPI_QtQuick;
extern sipTypeDef *sipExportedTypes_QtQuick[];

#define sipType_Qt_InputMethodQuery sipImportedTypes_QtQuick_QtCore[26].it_td

#define sipType_Qt_FocusReason sipImportedTypes_QtQuick_QtCore[25].it_td

#define sipType_Qt_FocusPolicy sipImportedTypes_QtQuick_QtCore[24].it_td

#define sipType_QObject sipImportedTypes_QtQuick_QtCore[11].it_td

#define sipType_QByteArray sipImportedTypes_QtQuick_QtCore[1].it_td

#define sipType_QEvent sipImportedTypes_QtQuick_QtCore[4].it_td

#define sipType_QTimerEvent sipImportedTypes_QtQuick_QtCore[21].it_td

#define sipType_QChildEvent sipImportedTypes_QtQuick_QtCore[3].it_td

#define sipType_QMetaMethod sipImportedTypes_QtQuick_QtCore[9].it_td

#define sipType_QPoint sipImportedTypes_QtQuick_QtCore[12].it_td

#define sipType_QPointF sipImportedTypes_QtQuick_QtCore[13].it_td

#define sipType_QRect sipImportedTypes_QtQuick_QtCore[14].it_td

#define sipType_QRectF sipImportedTypes_QtQuick_QtCore[15].it_td

#define sipType_QRunnable sipImportedTypes_QtQuick_QtCore[16].it_td

#define sipType_QSize sipImportedTypes_QtQuick_QtCore[17].it_td

#define sipType_QSizeF sipImportedTypes_QtQuick_QtCore[18].it_td

#define sipType_QThread sipImportedTypes_QtQuick_QtCore[20].it_td

#define sipType_QUrl sipImportedTypes_QtQuick_QtCore[22].it_td

#define sipType_QVariant sipImportedTypes_QtQuick_QtCore[23].it_td

#if !defined(sipType_QNativeInterface)
#define sipType_QNativeInterface sipImportedTypes_QtQuick_QtCore[10].it_td
#endif

#define sipType_QFlags_0100Qt_MouseButton sipImportedTypes_QtQuick_QtCore[6].it_td

#define sipType_QFlags_0100Qt_InputMethodQuery sipImportedTypes_QtQuick_QtCore[5].it_td

#define sipType_QMap_0100QString_0100QVariant sipImportedTypes_QtQuick_QtCore[8].it_td

#define sipType_QList_1800 sipImportedTypes_QtQuick_QtCore[7].it_td

#define sipType_QByteArrayList sipImportedTypes_QtQuick_QtCore[2].it_td

#define sipType_QString sipImportedTypes_QtQuick_QtCore[19].it_td

#define sipType_QAnyStringView sipImportedTypes_QtQuick_QtCore[0].it_td

#define sipType_qintptr sipImportedTypes_QtQuick_QtCore[27].it_td
extern sipImportedTypeDef sipImportedTypes_QtQuick_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtQuick_QtCore[];

#define sipType_QPaintDevice sipImportedTypes_QtQuick_QtGui[19].it_td

#define sipType_QPixmap sipImportedTypes_QtQuick_QtGui[22].it_td

#define sipType_QColor sipImportedTypes_QtQuick_QtGui[1].it_td

#define sipType_QCursor sipImportedTypes_QtQuick_QtGui[2].it_td

#define sipType_QKeyEvent sipImportedTypes_QtQuick_QtGui[13].it_td

#define sipType_QFocusEvent sipImportedTypes_QtQuick_QtGui[8].it_td

#define sipType_QPaintEvent sipImportedTypes_QtQuick_QtGui[20].it_td

#define sipType_QMoveEvent sipImportedTypes_QtQuick_QtGui[16].it_td

#define sipType_QResizeEvent sipImportedTypes_QtQuick_QtGui[24].it_td

#define sipType_QCloseEvent sipImportedTypes_QtQuick_QtGui[0].it_td

#define sipType_QShowEvent sipImportedTypes_QtQuick_QtGui[25].it_td

#define sipType_QHideEvent sipImportedTypes_QtQuick_QtGui[9].it_td

#define sipType_QInputMethodEvent sipImportedTypes_QtQuick_QtGui[12].it_td

#define sipType_QDropEvent sipImportedTypes_QtQuick_QtGui[6].it_td

#define sipType_QDragMoveEvent sipImportedTypes_QtQuick_QtGui[5].it_td

#define sipType_QDragEnterEvent sipImportedTypes_QtQuick_QtGui[3].it_td

#define sipType_QDragLeaveEvent sipImportedTypes_QtQuick_QtGui[4].it_td

#define sipType_QExposeEvent sipImportedTypes_QtQuick_QtGui[7].it_td

#define sipType_QMouseEvent sipImportedTypes_QtQuick_QtGui[15].it_td

#define sipType_QHoverEvent sipImportedTypes_QtQuick_QtGui[10].it_td

#define sipType_QWheelEvent sipImportedTypes_QtQuick_QtGui[33].it_td

#define sipType_QTabletEvent sipImportedTypes_QtQuick_QtGui[29].it_td

#define sipType_QTouchEvent sipImportedTypes_QtQuick_QtGui[32].it_td

#define sipType_QImage sipImportedTypes_QtQuick_QtGui[11].it_td

#define sipType_QMatrix4x4 sipImportedTypes_QtQuick_QtGui[14].it_td

#define sipType_QSurface sipImportedTypes_QtQuick_QtGui[26].it_td

#define sipType_QSurface_SurfaceType sipImportedTypes_QtQuick_QtGui[27].it_td

#define sipType_QOpenGLContext sipImportedTypes_QtQuick_QtGui[18].it_td

#define sipType_QWindow sipImportedTypes_QtQuick_QtGui[34].it_td

#define sipType_QPainter sipImportedTypes_QtQuick_QtGui[21].it_td

#define sipType_QRegion sipImportedTypes_QtQuick_QtGui[23].it_td

#define sipType_QSurfaceFormat sipImportedTypes_QtQuick_QtGui[28].it_td

#define sipType_QTextDocument sipImportedTypes_QtQuick_QtGui[30].it_td

#define sipType_QTextLayout sipImportedTypes_QtQuick_QtGui[31].it_td

#if !defined(sipType_QNativeInterface)
#define sipType_QNativeInterface sipImportedTypes_QtQuick_QtGui[17].it_td
#endif
extern sipImportedTypeDef sipImportedTypes_QtQuick_QtGui[];

#define sipType_QQmlEngine sipImportedTypes_QtQuick_QtQml[3].it_td

#define sipType_QQmlContext sipImportedTypes_QtQuick_QtQml[2].it_td

#define sipType_QQmlImageProviderBase sipImportedTypes_QtQuick_QtQml[4].it_td

#define sipType_QQmlImageProviderBase_ImageType sipImportedTypes_QtQuick_QtQml[5].it_td

#define sipType_QQmlIncubationController sipImportedTypes_QtQuick_QtQml[6].it_td

#define sipType_QQmlParserStatus sipImportedTypes_QtQuick_QtQml[7].it_td

#define sipType_QList_0100QQmlError sipImportedTypes_QtQuick_QtQml[1].it_td

#define sipType_QFlags_0100QQmlImageProviderBase_Flag sipImportedTypes_QtQuick_QtQml[0].it_td
extern sipImportedTypeDef sipImportedTypes_QtQuick_QtQml[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtQuick_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtQuick_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtQuick_qt_metacast;
#line 212 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQuick/qquickwindow.sip"
#include "qpyquick_api.h"
#line 2928 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipAPIQtQuick.h"

#endif
